package MultiLM;

use strict;
use warnings;
use Data::Dumper;

sub new 
  {
    my $c = shift;
    return bless {}, $c;
  }

sub init_learning
  { 
    shift->{n} = {};
  }

sub split_string
  {
    my ($s, $txt) = @_;

    $txt = lc($txt);
    $txt =~ s/[[:^alpha:]]//g;
    return [ split(//, $txt) ];
  }

sub learn_string
  {
    my ($s, $lang, $text) = @_;

    $s->{n}->{$lang}->{n}  ||= {};
    $s->{n}->{$lang}->{n2} ||= {};

    my $n  = $s->{n}->{$lang}->{n};
    my $n2 = $s->{n}->{$lang}->{n2};

    my $char_list = $s->split_string($text);
    my ($c0, @c)  = @$char_list;

    $n->{$c0}++;
    foreach my $c (@c)
      {
        $n->{$c}++;
        $n2->{"$c0$c"}++;
        $c0 = $c;
      }
  }

sub model
  {
     my $s = shift;

     return $s->tables unless exists $s->{n};

     my %m;
     foreach my $lang (keys %{$s->{n}})
       {
          $m{$lang} = {};
          foreach my $k ('n', 'n2')
            {
              my $h = $s->{n}->{$lang}->{$k};

              my %log_n;
              my $sig_n;
              foreach my $c (keys %$h)
                {
                  my $n = $h->{$c};
                  $sig_n    += $n;
                  $log_n{$c} = log($n);
                }

              $m{$lang}->{"log_sigma_$k"} = log($sig_n);
              $m{$lang}->{"log_$k"}       = \%log_n;
            }
        }

     return \%m;
  }

sub as_text
  {
     my $m = shift->model;

     my $txt = '';
     foreach my $lang (sort keys %$m)
       {
         my $n  = $m->{$lang}->{log_n};
         my $n2 = $m->{$lang}->{log_n2};

         my @x  = sort { $n->{$b}  <=> $n->{$a}  } keys %$n;
         my @x2 = sort { $n2->{$b} <=> $n2->{$a} } keys %$n2;

         $txt .= "Model for $lang:\n"
              .  "Common Letters:\n"      .  join(" ", @x)           . "\n"
              .  "Common Letter Pairs:\n" .  join(" ", @x2[0 .. 19]) . "\n"
              .  "\n";
       }

    return $txt;
  }    

sub save_as_perl
  {
    my ($s, $file) = @_;
    $file ||= "MultiLM.pm";
    
    # Read this file's contents:
    open(my $ih, '<', __FILE__) or die "Can't open self ?, ";
    my $full_src = join("", <$ih>);
    close($ih);

    # ... extract the relevant bits
    # which are marked with ##<...>##. The apparently spurious \s* in the regexps
    # avoid them matching with themselves...
    my @chunks   = ($full_src =~ /##\s*<start>\s*##\s*(.*?)##\s*<end>\s*##/gis);
    my $src      = join("", @chunks);

    # substitute the proper table declaration
    my $tables = $s->model_src;
    $src =~ s/##\s*<tables start>\s*##.*##\s*<tables end>\s*##\s*/$tables/is;
   
    open(my $fh, ">:utf8", $file)
      or die "Can't open $file: $!\n";
    print {$fh} $src;
  }

sub model_src
  {
     my $m = shift->model;

     my $data = Dumper($m);
     $data =~ s/^.*?=\s*//;

     return "sub tables { return $data }\n\n";
  }

sub languages
  {
    my $s = shift;
    return sort keys %{$s->tables};
  }

sub logprob_string
  {
    my ($s, $text) = @_;

    my $char_list = $s->split_string($text);
    my ($c00, @c) = @$char_list;

    return unless $c00;

    my $ft = $s->model;

    my %p;
    foreach my $lang (keys %$ft)
      {
        my $t  = $ft->{$lang};

        my $c0 = $c00;
        my $logprob = ($t->{log_n}->{$c0} || 0) - $t->{log_sigma_n};

        my $log_n2       = $t->{log_n2};
        my $log_sigma_n2 = $t->{log_sigma_n2};
        foreach my $c (@c)
          {
            $logprob += ($log_n2->{"$c0$c"} || 0) - $log_sigma_n2;
            $c0 = $c;
          }

        $p{$lang} = $logprob;
      }

    return \%p;
  }

sub prob_language
  {
    my $s     = shift;
    my $lp    = $s->logprob_string(@_);

    # Convert to scalar probs (biggest is 1.0 so normalization is
    # broken, but overflow is unlikely).
    my ($max) = sort values %$lp;;
    $_ = exp($_ - $max) foreach values %$lp;

    # Correct the normalization
    my $sig_p = 0.0;
    $sig_p += $_ foreach values %$lp;
    $_ /= $sig_p foreach values %$lp;

    return $lp;
  }

sub tables { return {
          'en' => {
                    'log_sigma_n2' => '14.8282010576443',
                    'log_n2' => {
                                  'sp' => '8.5387589693308',
                                  'ne' => '9.77866101958928',
                                  'tr' => '8.88765269032559',
                                  'ki' => '8.41294317004244',
                                  'gl' => '7.86825426552061',
                                  'hn' => '6.41999492814714',
                                  'xx' => '3.52636052461616',
                                  'sf' => '8.01697774676226',
                                  'ro' => '9.66402405235482',
                                  'pv' => '3.13549421592915',
                                  'fc' => '6.82328612235569',
                                  'lz' => '2.56494935746154',
                                  'vv' => '3.09104245335832',
                                  'zr' => '2.39789527279837',
                                  'br' => '8.04044688130311',
                                  'hd' => '6.03548143252476',
                                  'yv' => '5.34233425196481',
                                  'tc' => '8.04622910107538',
                                  'xk' => '0.693147180559945',
                                  'ke' => '9.02220192986066',
                                  'wd' => '6.11146733950268',
                                  'bk' => '0.693147180559945',
                                  'zk' => '0',
                                  'cs' => '5.06259503302697',
                                  'ow' => '9.45899571245912',
                                  'ji' => '6.23441072571837',
                                  'bf' => '3.25809653802148',
                                  'km' => '6.05678401322862',
                                  'af' => '8.03040956213048',
                                  'of' => '9.91041351260686',
                                  'yg' => '6.84906628263346',
                                  'dh' => '8.78385589664394',
                                  'tm' => '8.12177741916107',
                                  'ct' => '8.45190772471761',
                                  'jm' => '1.38629436111989',
                                  'pg' => '4.56434819146784',
                                  'ga' => '8.8309815109525',
                                  'oe' => '7.47477218239787',
                                  'ep' => '8.98080141357311',
                                  'ek' => '7.29233717617388',
                                  'lj' => '4.62497281328427',
                                  'zy' => '4.94875989037817',
                                  'mi' => '8.90625787815662',
                                  'pn' => '4.40671924726425',
                                  'ul' => '9.03717675296699',
                                  'sv' => '6.40357419793482',
                                  'mq' => '3.46573590279973',
                                  'fa' => '8.75668242126653',
                                  'za' => '6.65157187358973',
                                  'xo' => '4.59511985013459',
                                  'kt' => '7.11558212618445',
                                  'fh' => '7.74022952476318',
                                  'uy' => '4.9416424226093',
                                  'ai' => '9.25234566612121',
                                  'uv' => '4.74493212836325',
                                  've' => '9.80200838358627',
                                  'na' => '9.23561817916045',
                                  'pq' => '2.39789527279837',
                                  'gj' => '4.85203026391962',
                                  'ba' => '8.19973896063079',
                                  'ub' => '7.41818082272679',
                                  'rf' => '7.7848892956551',
                                  'kz' => '0',
                                  'ma' => '9.43260353586309',
                                  'in' => '10.8474518154988',
                                  'qh' => '0',
                                  'id' => '9.23707966916581',
                                  'si' => '9.54695545553714',
                                  'ft' => '8.99702338147971',
                                  'me' => '9.76566123562873',
                                  're' => '10.4215668050134',
                                  'om' => '9.57366316988638',
                                  'dd' => '8.0727793331695',
                                  'by' => '8.05610965954506',
                                  'fi' => '8.66302363962778',
                                  'vm' => '2.83321334405622',
                                  'gs' => '7.91971976092457',
                                  'ir' => '8.92572027356022',
                                  'wo' => '8.81640849968169',
                                  'dq' => '4.96284463025991',
                                  'tz' => '4.68213122712422',
                                  'uo' => '5.61677109766657',
                                  'cg' => '2.89037175789616',
                                  'ii' => '5.35185813347607',
                                  'hv' => '4.21950770517611',
                                  'xa' => '5.81413053182507',
                                  'jo' => '7.0343879299155',
                                  'bi' => '7.66340766489348',
                                  'ry' => '8.7558950816463',
                                  'uq' => '2.484906649788',
                                  'kj' => '3.58351893845611',
                                  'fl' => '7.650168700845',
                                  'nk' => '7.83913164827433',
                                  'mn' => '6.38856140554563',
                                  'nv' => '6.7696419768525',
                                  'gd' => '6.41345895716736',
                                  'ot' => '9.6142709699924',
                                  'lc' => '6.68085467879022',
                                  'ah' => '7.16006920759613',
                                  'lm' => '7.3375877435386',
                                  'zq' => '0',
                                  'ag' => '8.55275336681479',
                                  'on' => '10.285547552198',
                                  'cr' => '7.95120715647297',
                                  'sg' => '7.38336814699238',
                                  'kh' => '6.7093043402583',
                                  'ov' => '8.10892415597534',
                                  'vu' => '3.73766961828337',
                                  'dw' => '8.39728289474368',
                                  'ih' => '7.27517231945277',
                                  'hj' => '4.63472898822964',
                                  'rl' => '8.02256894698825',
                                  'eh' => '9.06323150693797',
                                  'gk' => '4.34380542185368',
                                  'ea' => '10.1977603583119',
                                  'gm' => '6.8001700683022',
                                  'xy' => '3.09104245335832',
                                  'bg' => '2.39789527279837',
                                  'aw' => '8.16678428905615',
                                  'gy' => '6.21060007702465',
                                  'sq' => '6.15060276844628',
                                  'ca' => '9.0146903849709',
                                  'zz' => '5.37989735354046',
                                  'pp' => '7.94697135769359',
                                  'xr' => '2.63905732961526',
                                  'zb' => '2.484906649788',
                                  'dg' => '7.63867982387611',
                                  'hq' => '3.2188758248682',
                                  'rd' => '8.75966867102994',
                                  'fu' => '7.67971363996637',
                                  'es' => '10.3453488758356',
                                  'jh' => '1.09861228866811',
                                  'sw' => '8.68423189134568',
                                  'bx' => '0',
                                  'lp' => '6.92461239604856',
                                  'sa' => '9.84601732538158',
                                  'yf' => '7.46508273639955',
                                  'xb' => '3.04452243772342',
                                  'ie' => '8.7059937143079',
                                  'tl' => '8.58597270681106',
                                  'nd' => '10.4601561446104',
                                  'tj' => '5.8348107370626',
                                  'cf' => '3.93182563272433',
                                  'pd' => '4.51085950651685',
                                  'de' => '9.53683442021335',
                                  'un' => '9.08692902706095',
                                  'rk' => '7.68386398025643',
                                  'fm' => '7.08506429395255',
                                  'md' => '5.86929691313377',
                                  'cl' => '7.87435882472988',
                                  'jp' => '1.79175946922805',
                                  'wt' => '6.98378996525813',
                                  'up' => '8.39818440483404',
                                  'hz' => '1.94591014905531',
                                  'sx' => '2.07944154167984',
                                  'vn' => '1.94591014905531',
                                  'wz' => '1.6094379124341',
                                  'ib' => '7.4205789054108',
                                  'he' => '11.2753025923912',
                                  'rx' => '3.66356164612965',
                                  'ex' => '7.78613643778307',
                                  'zh' => '2.83321334405622',
                                  'yj' => '5.75890177387728',
                                  'dj' => '6.24027584517077',
                                  'wn' => '8.07651532755233',
                                  'vt' => '2.484906649788',
                                  'wm' => '6.09807428216624',
                                  'da' => '9.41344446795267',
                                  'ug' => '8.32093496888341',
                                  'ju' => '7.29709100516042',
                                  'zg' => '3.13549421592915',
                                  'wk' => '4.30406509320417',
                                  'ci' => '7.90211754627645',
                                  'yy' => '6.32256523992728',
                                  'hb' => '6.61069604471776',
                                  'jl' => '1.38629436111989',
                                  'ta' => '9.64652865272719',
                                  'gz' => '2.70805020110221',
                                  'rw' => '8.09894674894334',
                                  'hs' => '7.350516171834',
                                  'll' => '9.79406323525484',
                                  'aq' => '5.11198778835654',
                                  'em' => '9.36947859331448',
                                  'qr' => '0',
                                  'mo' => '8.92145757894788',
                                  'ps' => '7.38150189450671',
                                  'av' => '8.65207367361006',
                                  'ao' => '5.4249500174814',
                                  'is' => '10.0430755667432',
                                  'qu' => '7.94378269245863',
                                  'ut' => '9.45124525286903',
                                  'mt' => '7.79482315217939',
                                  'ok' => '8.15765701519647',
                                  'la' => '9.35288105875829',
                                  'gi' => '8.4069317971587',
                                  'bh' => '4.27666611901606',
                                  'bt' => '5.95583736946483',
                                  'gb' => '7.02908756414966',
                                  'zc' => '1.94591014905531',
                                  'oc' => '8.16422565226583',
                                  'xm' => '3.36729582998647',
                                  'tx' => '2.484906649788',
                                  'nx' => '4.60517018598809',
                                  'hp' => '6.1527326947041',
                                  'pb' => '5.48063892334199',
                                  'dv' => '6.51174532964473',
                                  'ng' => '10.1758021478568',
                                  'yp' => '7.26682734752059',
                                  'gt' => '8.35161075062656',
                                  'od' => '8.56445838388335',
                                  'hi' => '10.0984785124307',
                                  'eg' => '8.41759382619348',
                                  'ya' => '8.46104603079324',
                                  'um' => '7.93056585423396',
                                  'cb' => '3.91202300542815',
                                  'os' => '8.99156227817161',
                                  'ey' => '8.94546295217767',
                                  'fr' => '8.44741429680832',
                                  'tu' => '8.43468076984177',
                                  'ra' => '9.57664876488315',
                                  'ic' => '9.18860587983018',
                                  'sr' => '7.24136628332232',
                                  'vo' => '6.98100574072173',
                                  'fj' => '4.88280192258637',
                                  'py' => '6.289715570909',
                                  'pm' => '5.34233425196481',
                                  'nm' => '7.59588991771854',
                                  'sd' => '7.60589000105312',
                                  'cj' => '1.09861228866811',
                                  'ei' => '9.31226499169811',
                                  'ha' => '10.3214081019116',
                                  'fb' => '6.56807791141198',
                                  'lg' => '6.10031895202006',
                                  'fq' => '3.43398720448515',
                                  'gh' => '9.18440698994968',
                                  'bc' => '3.55534806148941',
                                  'mr' => '7.87283617502572',
                                  'jc' => '2.39789527279837',
                                  'rm' => '8.34474275441755',
                                  'kn' => '7.80913539812054',
                                  'rn' => '8.43620003220671',
                                  'kb' => '5.8406416573734',
                                  'ym' => '7.6231530684769',
                                  'ik' => '7.64921631982063',
                                  'uh' => '6.3491389913798',
                                  'vd' => '0',
                                  'xe' => '5.79909265446053',
                                  'zj' => '0.693147180559945',
                                  'mg' => '5.49306144334055',
                                  'ux' => '3.58351893845611',
                                  'db' => '8.43706714693695',
                                  'ob' => '8.25244609024695',
                                  'oa' => '8.20740183337636',
                                  'ru' => '8.02975852044082',
                                  'wy' => '5.94017125272043',
                                  'ku' => '5.35185813347607',
                                  'lo' => '9.41889806496197',
                                  'mz' => '1.6094379124341',
                                  'lb' => '7.07072410726028',
                                  'xw' => '3.89182029811063',
                                  'ml' => '6.22257626807137',
                                  'bj' => '5.76832099579377',
                                  'wl' => '6.53958595561767',
                                  'rv' => '6.95654544315157',
                                  'zp' => '2.484906649788',
                                  'xf' => '3.93182563272433',
                                  'mf' => '6.4425401664682',
                                  'pr' => '8.65817178467581',
                                  'ap' => '8.53836742664764',
                                  'fk' => '4.65396035015752',
                                  'nf' => '7.69165682281055',
                                  'di' => '9.50703173858555',
                                  'uw' => '6.62007320653036',
                                  'ip' => '7.43248380791712',
                                  'zd' => '2.30258509299405',
                                  'kl' => '6.48920493132532',
                                  'we' => '9.190545744648',
                                  'bs' => '6.64509096950564',
                                  'ol' => '9.02087334702136',
                                  'to' => '10.2921455423279',
                                  'cu' => '7.70165236264223',
                                  'yu' => '5.99893656194668',
                                  'ch' => '9.3180281773931',
                                  'eu' => '7.29776828253138',
                                  'mu' => '8.021256180144',
                                  'wa' => '9.67205978163422',
                                  'zf' => '2.07944154167984',
                                  'pl' => '8.352318548226',
                                  'ay' => '9.01432548805023',
                                  'xp' => '6.64248680136726',
                                  'ds' => '9.05532264970957',
                                  'pe' => '9.01699831189876',
                                  'an' => '10.7100973380069',
                                  'ua' => '7.722677516468',
                                  'ef' => '8.9099107267019',
                                  'tt' => '9.65617937422262',
                                  'oy' => '7.50823877467866',
                                  'ss' => '9.41702928521843',
                                  'or' => '10.0061343894963',
                                  'cc' => '7.09506437728713',
                                  'nw' => '8.03851202097681',
                                  'fs' => '7.26892012819372',
                                  'xh' => '4.27666611901606',
                                  'th' => '11.3017722415076',
                                  'hk' => '4.29045944114839',
                                  'er' => '10.8099703434192',
                                  'dc' => '7.59689443814454',
                                  'iz' => '7.01211529430638',
                                  'hc' => '6.37331978957701',
                                  'hr' => '7.62364194651157',
                                  'gn' => '6.94312242281943',
                                  'yh' => '7.82204400818562',
                                  'kd' => '5.03695260241363',
                                  'kc' => '5.35658627467201',
                                  'zi' => '4.99721227376411',
                                  'vc' => '0',
                                  'cv' => '2.07944154167984',
                                  'dp' => '7.45124168498768',
                                  'hw' => '7.0604763659998',
                                  'ws' => '7.17548971362422',
                                  'rg' => '7.79193595693806',
                                  'dy' => '8.1300590399928',
                                  'ad' => '9.30401284783882',
                                  'sz' => '3.55534806148941',
                                  'ja' => '6.75809450442773',
                                  'jn' => '0',
                                  'zw' => '3.87120101090789',
                                  'vp' => '1.38629436111989',
                                  'nl' => '7.82923253754359',
                                  'vs' => '2.30258509299405',
                                  'el' => '9.73358851574073',
                                  'ij' => '4.67282883446191',
                                  'kk' => '4.06044301054642',
                                  'hh' => '7.50878717063428',
                                  'gg' => '7.14045304310116',
                                  'eb' => '8.76248954737158',
                                  'mm' => '7.32184971378836',
                                  'sj' => '6.41673228251233',
                                  'fx' => '0',
                                  'my' => '8.26693534761046',
                                  'hg' => '5.59842195899838',
                                  'yd' => '7.56371966841437',
                                  'jj' => '4.29045944114839',
                                  'iv' => '8.26693534761046',
                                  'tn' => '7.52940645783701',
                                  'rt' => '9.36451962282386',
                                  'co' => '9.4864558080565',
                                  'yk' => '5.71702770140622',
                                  'bo' => '8.68118104152169',
                                  'cy' => '6.71659477352098',
                                  'zo' => '5.14166355650266',
                                  'ck' => '8.65712903171375',
                                  'bv' => '3.97029191355212',
                                  'wv' => '3.8286413964891',
                                  'lw' => '7.26961674960817',
                                  'yw' => '8.10016144693661',
                                  'oi' => '8.22523532410167',
                                  'bu' => '8.62353322718756',
                                  'dm' => '8.10198073185319',
                                  'ls' => '8.05864371221562',
                                  'mv' => '4.23410650459726',
                                  'ri' => '9.56395062454207',
                                  'ti' => '9.95807043030642',
                                  'ky' => '6.31173480915291',
                                  'ka' => '7.39326309476384',
                                  'ue' => '7.70751219460034',
                                  'wc' => '5.605802066296',
                                  'ze' => '6.51025834052315',
                                  'hu' => '7.65349490966125',
                                  'se' => '9.87421320983213',
                                  'lf' => '7.89803969076462',
                                  'iq' => '4.52178857704904',
                                  'xv' => '2.89037175789616',
                                  'kv' => '3.49650756146648',
                                  'kq' => '3.04452243772342',
                                  'jw' => '2.39789527279837',
                                  'ph' => '7.58528107863913',
                                  'dx' => '0.693147180559945',
                                  'no' => '9.68377560652361',
                                  'nh' => '8.34759040703006',
                                  'lv' => '6.3261494731551',
                                  'rb' => '7.89989532313973',
                                  'tf' => '7.68294316987829',
                                  'xt' => '6.59441345974978',
                                  'ln' => '6.27287700654617',
                                  'wh' => '9.39723479061527',
                                  'iy' => '3.55534806148941',
                                  'ox' => '5.4510384535657',
                                  'uj' => '4.04305126783455',
                                  'ab' => '8.75557997214314',
                                  'uu' => '4.20469261939097',
                                  'rz' => '3.13549421592915',
                                  'js' => '0.693147180559945',
                                  'li' => '9.64361518072361',
                                  'td' => '7.60290046220476',
                                  'yr' => '7.07834157955767',
                                  'oq' => '4.67282883446191',
                                  'fp' => '6.49828214947643',
                                  'gv' => '4.64439089914137',
                                  'pa' => '8.73004395324502',
                                  'xg' => '1.09861228866811',
                                  'am' => '8.91018077801329',
                                  'tv' => '5.63835466933375',
                                  'wj' => '3.71357206670431',
                                  'ee' => '9.48554492291685',
                                  'cd' => '4.64439089914137',
                                  'pk' => '3.68887945411394',
                                  'cp' => '4.35670882668959',
                                  'eo' => '9.06658546833104',
                                  'fy' => '6.81014245011514',
                                  'go' => '8.83710041116275',
                                  'qy' => '0',
                                  'nz' => '4.58496747867057',
                                  'mj' => '4.35670882668959',
                                  'as' => '10.0448134886266',
                                  'wr' => '6.80461452006262',
                                  'vr' => '2.63905732961526',
                                  'ae' => '5.12396397940326',
                                  'rs' => '9.38420964195515',
                                  'cn' => '3.40119738166216',
                                  'du' => '7.83834331555712',
                                  'jb' => '1.38629436111989',
                                  'ia' => '8.18060094759445',
                                  'mx' => '0',
                                  'cx' => '0',
                                  'sy' => '7.34277918933185',
                                  'df' => '7.85243908535751',
                                  'vi' => '8.10500553754725',
                                  'rh' => '8.20603776277881',
                                  'bm' => '4.11087386417331',
                                  'xn' => '1.79175946922805',
                                  'nr' => '6.80239476332431',
                                  'vb' => '1.79175946922805',
                                  'bz' => '0',
                                  'kw' => '6.43615036836943',
                                  'gf' => '6.77078942390898',
                                  'al' => '9.77593823158915',
                                  'uf' => '6.42162226780652',
                                  'uz' => '4.94875989037817',
                                  'cw' => '5.04342511691925',
                                  'ht' => '9.00601857490256',
                                  'nt' => '10.2383513534607',
                                  'pc' => '4.67282883446191',
                                  'mw' => '6.95177216439891',
                                  'yo' => '9.42529044826187',
                                  'xc' => '6.21860011969173',
                                  'wi' => '9.34626888920043',
                                  'iw' => '7.48773376143644',
                                  'yz' => '2.70805020110221',
                                  'gc' => '6.42162226780652',
                                  'gu' => '7.70706265537047',
                                  'wq' => '2.77258872223978',
                                  'lq' => '3.68887945411394',
                                  'xu' => '3.49650756146648',
                                  'dr' => '8.1961611392829',
                                  'ac' => '9.05916858417444',
                                  'yb' => '7.78364059622125',
                                  'oj' => '6.38012253689976',
                                  'sk' => '7.37650812632622',
                                  'vy' => '5.35658627467201',
                                  'ty' => '8.47595444339964',
                                  'qd' => '0.693147180559945',
                                  'yn' => '7.08002649992259',
                                  'qc' => '0.693147180559945',
                                  'ax' => '5.25227342804663',
                                  'vh' => '1.09861228866811',
                                  'kp' => '5.16478597392351',
                                  'bb' => '6.3491389913798',
                                  'xs' => '3.49650756146648',
                                  'nq' => '5.59471137960184',
                                  'et' => '10.0817174164268',
                                  'im' => '9.1433455031519',
                                  'mk' => '4.39444915467244',
                                  'vj' => '1.6094379124341',
                                  'en' => '10.3017937634458',
                                  'pj' => '3.25809653802148',
                                  'ed' => '10.3138075233705',
                                  'ui' => '7.68662133494462',
                                  'zu' => '2.484906649788',
                                  'dl' => '8.04430540699064',
                                  'qm' => '0',
                                  'nn' => '7.98684490116138',
                                  'bn' => '3.66356164612965',
                                  'ix' => '6.16541785423142',
                                  'jt' => '1.6094379124341',
                                  'pz' => '1.09861228866811',
                                  'gp' => '6.24027584517077',
                                  'pu' => '7.51806418123308',
                                  'mb' => '7.69984240739699',
                                  'fz' => '1.38629436111989',
                                  'ar' => '9.96749468251042',
                                  'sm' => '8.24800570160062',
                                  'ny' => '8.16933639592839',
                                  'xj' => '0.693147180559945',
                                  'ww' => '6.65415252018322',
                                  'bl' => '8.74097653801779',
                                  'bd' => '3.95124371858143',
                                  'mc' => '6.21260609575152',
                                  'le' => '9.85434982797458',
                                  'rr' => '8.21608809863232',
                                  'xi' => '5.82304589548302',
                                  'if' => '8.3537326422632',
                                  'nu' => '7.33888813383888',
                                  'xd' => '3.09104245335832',
                                  'fe' => '8.54461378699223',
                                  'rq' => '4.45434729625351',
                                  'dk' => '6.02586597382531',
                                  'nc' => '8.88350158432321',
                                  'st' => '10.2650356035778',
                                  'hm' => '7.00850518208228',
                                  'ko' => '7.09007683577609',
                                  'ak' => '8.12444685571585',
                                  'oo' => '9.35018926709258',
                                  'nj' => '6.10255859461357',
                                  'gq' => '3.85014760171006',
                                  'ge' => '8.97132147150368',
                                  'fv' => '4.98360662170834',
                                  'lh' => '6.97166860472579',
                                  'gr' => '8.20275638165564',
                                  'va' => '7.20042489294496',
                                  'hy' => '7.31455283232408',
                                  'ms' => '7.96241568012106',
                                  'ys' => '8.78813593986372',
                                  'uc' => '8.34188696951619',
                                  'rc' => '8.17835816560584',
                                  'wf' => '5.8664680569333',
                                  'it' => '10.1574706390013',
                                  'rj' => '5.7268477475872',
                                  'sb' => '8.24617155985756',
                                  'ly' => '9.16230492293763',
                                  'lu' => '7.80994708647679',
                                  'dn' => '8.24143968982973',
                                  'zv' => '1.6094379124341',
                                  'pt' => '7.68708015578313',
                                  'il' => '9.12706745278236',
                                  'ks' => '7.55381085200823',
                                  'mh' => '6.95272864462487',
                                  'xq' => '2.94443897916644',
                                  'oz' => '4.64439089914137',
                                  'zn' => '1.79175946922805',
                                  'kg' => '4.44265125649032',
                                  'pf' => '5.50938833662798',
                                  'og' => '7.64204440287326',
                                  'ho' => '9.53300341332321',
                                  'tb' => '8.07930819205196',
                                  'zt' => '3.04452243772342',
                                  'jy' => '0',
                                  'wu' => '5.04985600724954',
                                  'ud' => '7.56164174558878',
                                  'ff' => '8.13358741766097',
                                  'vg' => '0.693147180559945',
                                  'sn' => '7.90322680873073',
                                  'yc' => '7.62070508683826',
                                  'yi' => '8.15017926968233',
                                  'hl' => '6.3578422665081',
                                  'sl' => '8.17413934342947',
                                  'ew' => '9.4129546320379',
                                  'au' => '7.91352101728389',
                                  'us' => '9.21512888870798',
                                  'fn' => '5.76832099579377',
                                  'qt' => '1.38629436111989',
                                  'ye' => '8.25582842728183',
                                  'dz' => '2.70805020110221',
                                  'tq' => '4.99721227376411',
                                  'cm' => '3.87120101090789',
                                  'jk' => '0.693147180559945',
                                  'bw' => '3.93182563272433',
                                  'lk' => '7.21670948670946',
                                  'jg' => '0',
                                  'tk' => '6.32076829425058',
                                  'su' => '8.60428789826717',
                                  'sc' => '8.40536737623398',
                                  'nb' => '7.76429600645052',
                                  'yl' => '7.35179986905778',
                                  'vw' => '1.94591014905531',
                                  'az' => '5.85507192220243',
                                  'ec' => '9.43116122792075',
                                  'po' => '8.73069036567864',
                                  'aj' => '5.52146091786225',
                                  'aa' => '5.93224518744801',
                                  'eq' => '6.75576892198425',
                                  'ez' => '5.06259503302697',
                                  'ts' => '9.19542975924043',
                                  'fw' => '6.76388490856244',
                                  'xl' => '2.56494935746154',
                                  'yq' => '4.27666611901606',
                                  'lr' => '6.52795791762255',
                                  'rp' => '7.60986220091355',
                                  'np' => '6.99484998583307',
                                  'do' => '9.37534620656045',
                                  'mp' => '8.11282747875137',
                                  'zl' => '4.45434729625351',
                                  'iu' => '5.73657229747919',
                                  'wg' => '4.70048036579242',
                                  'oh' => '8.08394570229562',
                                  'fd' => '6.25575004175337',
                                  'ni' => '9.14420056947164',
                                  'pw' => '5.82008293035236',
                                  'wb' => '5.84643877505772',
                                  'ej' => '6.60258789218934',
                                  'yx' => '1.09861228866811',
                                  'ld' => '9.09245733131947',
                                  'jd' => '1.79175946922805',
                                  'uk' => '6.24610676548156',
                                  'kf' => '6.00388706710654',
                                  'vf' => '1.6094379124341',
                                  'gw' => '7.19518732017871',
                                  'vl' => '1.6094379124341',
                                  'tp' => '7.39449310721904',
                                  'kr' => '4.85981240436167',
                                  'je' => '7.09589322109753',
                                  'fo' => '9.27030595314362',
                                  'yt' => '8.53503310954457',
                                  'sh' => '9.68973724623851',
                                  'io' => '8.89658807179122',
                                  'zs' => '2.63905732961526',
                                  'zm' => '2.83321334405622',
                                  'so' => '9.58932460283475',
                                  'cz' => '2.19722457733622',
                                  'lt' => '8.30992298925832',
                                  'be' => '9.57261958263475',
                                  'wp' => '4.93447393313069',
                                  'jr' => '1.09861228866811',
                                  'op' => '8.38114434695296',
                                  'ur' => '9.36134324551271',
                                  'bp' => '3.46573590279973',
                                  'dt' => '9.39773238558324',
                                  'qo' => '0.693147180559945',
                                  'tw' => '8.9459841248279',
                                  'ce' => '9.25569607369698',
                                  'ev' => '8.74448811385292',
                                  'at' => '10.2644084695597',
                                  'pi' => '8.16080392095467',
                                  'tg' => '7.2902928824466',
                                  'cq' => '5.11198778835654',
                                  'ou' => '10.3784787232929',
                                  'te' => '9.99802470636012',
                                  'ig' => '8.830689198761',
                                  'ns' => '9.19532825185568',
                                  'hf' => '6.35088571671474',
                                  'jf' => '1.38629436111989',
                                  'fg' => '5.85793315448346'
                                },
                    'log_n' => {
                                 'w' => '11.1084848319083',
                                 'r' => '11.9617246097771',
                                 'a' => '12.2976166512868',
                                 'd' => '11.7007651024481',
                                 'x' => '8.17329343896623',
                                 'j' => '8.58110651715989',
                                 'y' => '11.0057930130419',
                                 'u' => '11.2987912078136',
                                 'h' => '12.0513292901054',
                                 'k' => '10.1720250311402',
                                 'g' => '11.0093567791521',
                                 'f' => '10.9838510061474',
                                 't' => '12.4068806042986',
                                 'i' => '12.1507766140262',
                                 'e' => '12.7173321751454',
                                 'n' => '12.1557841093619',
                                 'v' => '10.0929502174814',
                                 'm' => '11.1827950762536',
                                 's' => '12.0542434356718',
                                 'l' => '11.6768199479604',
                                 'p' => '10.7491412048108',
                                 'c' => '11.1084548621777',
                                 'b' => '10.7489480116493',
                                 'q' => '7.94873845481361',
                                 'z' => '7.79811262882979',
                                 'o' => '12.2778163965428'
                               },
                    'log_sigma_n' => '14.8282028738445'
                  },
          'fr' => {
                    'log_sigma_n2' => '14.3823272144459',
                    'log_n2' => {
                                  'ne' => '9.81246815414896',
                                  'sp' => '8.96469555531546',
                                  'ki' => '4.4188406077966',
                                  'tr' => '9.4837206597171',
                                  'gl' => '6.3818160174061',
                                  'hn' => '4.11087386417331',
                                  'sf' => '7.62168499872461',
                                  'ro' => '8.96661138705286',
                                  'pv' => '3.2188758248682',
                                  'fc' => '4.74493212836325',
                                  'lz' => '2.56494935746154',
                                  'vv' => '0.693147180559945',
                                  'zr' => '3.71357206670431',
                                  'br' => '7.46908388492123',
                                  'yv' => '3.85014760171006',
                                  'hd' => '5.00394630594546',
                                  'tc' => '8.36427508499152',
                                  'xk' => '1.09861228866811',
                                  'ke' => '4.54329478227',
                                  'wd' => '1.38629436111989',
                                  'cs' => '5.87773578177964',
                                  'ji' => '3.68887945411394',
                                  'ow' => '4.72738781871234',
                                  'bf' => '0',
                                  'km' => '1.6094379124341',
                                  'af' => '7.44541755670169',
                                  'of' => '6.89972310728487',
                                  'yg' => '2.94443897916644',
                                  'dh' => '5.90536184805457',
                                  'tm' => '8.01268092970684',
                                  'ct' => '8.14177220465645',
                                  'qp' => '0',
                                  'jm' => '2.39789527279837',
                                  'pg' => '3.97029191355212',
                                  'oe' => '5.64897423816121',
                                  'ga' => '7.40427911803727',
                                  'ep' => '9.32607687045878',
                                  'lj' => '5.24174701505964',
                                  'ek' => '2.94443897916644',
                                  'zy' => '2.19722457733622',
                                  'mi' => '8.26487826280175',
                                  'pn' => '4.8283137373023',
                                  'ul' => '8.2845042272585',
                                  'sv' => '7.50933526601659',
                                  'mq' => '3.93182563272433',
                                  'fa' => '8.40827078419205',
                                  'za' => '4.52178857704904',
                                  'xo' => '4.70953020131233',
                                  'kt' => '2.83321334405622',
                                  'fh' => '1.79175946922805',
                                  'uy' => '5.01727983681492',
                                  "l\x{153}" => '3.78418963391826',
                                  'ai' => '10.5430493401723',
                                  'uv' => '8.3291754420774',
                                  've' => '9.11107237031751',
                                  'na' => '9.03419967425731',
                                  'gj' => '1.94591014905531',
                                  'pq' => '4.17438726989564',
                                  'ba' => '7.17395831975679',
                                  'ub' => '6.95177216439891',
                                  'rf' => '6.75110146893676',
                                  'ma' => '9.33246950520925',
                                  'qh' => '2.19722457733622',
                                  'in' => '9.61900037098087',
                                  'id' => '8.18255926406867',
                                  'si' => '9.32723412344768',
                                  'ft' => '6.36302810354046',
                                  're' => '10.3605958937961',
                                  'me' => '9.82957186958596',
                                  'om' => '8.92025541490809',
                                  'dd' => '6.41999492814714',
                                  'by' => '4.63472898822964',
                                  'fi' => '7.93415523353632',
                                  'vm' => '2.83321334405622',
                                  'gs' => '5.16478597392351',
                                  'ir' => '9.3652050825371',
                                  'wo' => '5.79909265446053',
                                  'dq' => '5.25749537202778',
                                  'tz' => '2.70805020110221',
                                  'uo' => '7.13009851012558',
                                  'cg' => '3.04452243772342',
                                  'ii' => '5.94803498918065',
                                  'hv' => '3.25809653802148',
                                  'xa' => '6.20050917404269',
                                  'jo' => '7.75061473277041',
                                  'bi' => '7.82204400818562',
                                  'ry' => '5.2040066870768',
                                  'uq' => '6.33859407820318',
                                  'fl' => '6.73340189183736',
                                  'nk' => '3.36729582998647',
                                  'mn' => '5.06890420222023',
                                  'gd' => '5.27811465923052',
                                  'nv' => '7.52779398772144',
                                  'ot' => '7.88306935130575',
                                  'lc' => '6.61069604471776',
                                  'ah' => '5.56452040732269',
                                  'lm' => '6.62539236800796',
                                  'zq' => '4.77068462446567',
                                  'ag' => '8.1610895128458',
                                  'on' => '10.1140725746029',
                                  'cr' => '7.76472054477148',
                                  'sg' => '6.96885037834195',
                                  'kh' => '0',
                                  'ov' => '5.4553211153577',
                                  'vu' => '6.33505425149806',
                                  'dw' => '4.35670882668959',
                                  'ih' => '4.26267987704132',
                                  'hj' => '3.46573590279973',
                                  "t\x{153}" => '1.38629436111989',
                                  'rl' => '8.53660358493606',
                                  'eh' => '6.69084227741856',
                                  'ea' => '8.84779106484485',
                                  'gm' => '4.11087386417331',
                                  "\x{153}d" => '0',
                                  'xy' => '4.26267987704132',
                                  'bg' => '1.6094379124341',
                                  'aw' => '4.18965474202643',
                                  'gy' => '2.99573227355399',
                                  'sq' => '8.72258002114119',
                                  'ca' => '8.12266802334641',
                                  'zz' => '2.07944154167984',
                                  'pp' => '7.63240112660145',
                                  'xr' => '4.52178857704904',
                                  'zb' => '4.06044301054642',
                                  'dg' => '4.74493212836325',
                                  'hq' => '3.93182563272433',
                                  'rd' => '8.78981238619097',
                                  'fu' => '6.74170069465205',
                                  'es' => '10.6870465719563',
                                  'jh' => '2.07944154167984',
                                  'sw' => '7.17011954344963',
                                  'lp' => '6.71659477352098',
                                  'sa' => '9.64023789622493',
                                  'yf' => '4.40671924726425',
                                  'xb' => '4.58496747867057',
                                  'ie' => '9.53733930680491',
                                  'tl' => '8.72111314776269',
                                  'qq' => '0.693147180559945',
                                  'nd' => '9.4097648366698',
                                  'tj' => '7.08673793451058',
                                  'cf' => '3.76120011569356',
                                  "b\x{153}" => '2.63905732961526',
                                  'pd' => '5.41164605185504',
                                  'de' => '10.3239069524261',
                                  'un' => '9.43747594455993',
                                  'rk' => '5.93753620508243',
                                  'md' => '6.4723462945009',
                                  'fm' => '3.97029191355212',
                                  'cl' => '7.47647238116391',
                                  'jp' => '4.24849524204936',
                                  'wt' => '3.3322045101752',
                                  'up' => '7.91498300584839',
                                  'sx' => '2.83321334405622',
                                  'vn' => '4.62497281328427',
                                  'ib' => '7.14913159855741',
                                  'he' => '8.5814816812986',
                                  'ex' => '7.35244110024358',
                                  'zh' => '1.79175946922805',
                                  'yj' => '2.99573227355399',
                                  'dj' => '6.49828214947643',
                                  'wn' => '3.46573590279973',
                                  'vt' => '4.71849887129509',
                                  'da' => '8.98117874833641',
                                  'ug' => '6.37672694789863',
                                  'ju' => '6.61472560020376',
                                  'zg' => '3.17805383034795',
                                  'ci' => '7.96380795323145',
                                  'yy' => '3.17805383034795',
                                  'hb' => '4.36944785246702',
                                  'jl' => '3.63758615972639',
                                  'ta' => '9.62747051161485',
                                  'rw' => '3.85014760171006',
                                  'hs' => '5.26269018890489',
                                  'll' => '9.50487391937707',
                                  'aq' => '6.78332520060396',
                                  'em' => '9.6956020036109',
                                  'mo' => '8.81343849452851',
                                  'ps' => '7.0343879299155',
                                  'av' => '9.24232341782923',
                                  'ao' => '5.56452040732269',
                                  'is' => '10.0141788343788',
                                  'ut' => '9.06473639811739',
                                  'qu' => '10.2150082144678',
                                  'mt' => '5.8348107370626',
                                  'ok' => '4.35670882668959',
                                  'gi' => '7.15851399732932',
                                  'la' => '9.88093514806562',
                                  'bh' => '0',
                                  'gb' => '2.484906649788',
                                  'bt' => '5.22035582507832',
                                  "e\x{153}" => '3.17805383034795',
                                  'zc' => '4.77912349311153',
                                  'oc' => '7.38087903556412',
                                  'xm' => '5.54517744447956',
                                  'tx' => '1.94591014905531',
                                  'nx' => '3.68887945411394',
                                  'hp' => '4.4188406077966',
                                  'pb' => '2.83321334405622',
                                  'dv' => '4.99043258677874',
                                  'ng' => '7.90544164906029',
                                  'yp' => '5.47227067367148',
                                  'gt' => '6.36990098282823',
                                  'od' => '7.15929190479756',
                                  'qi' => '0',
                                  'jv' => '2.39789527279837',
                                  'hi' => '7.06731984865348',
                                  'eg' => '7.68432406768116',
                                  'ya' => '7.55066124310534',
                                  'um' => '7.67322312112171',
                                  'cb' => '3.43398720448515',
                                  'os' => '8.00503334463711',
                                  'ey' => '5.06890420222023',
                                  'fr' => '7.67415292128168',
                                  'tu' => '8.32069157104845',
                                  'ra' => '9.57512236480881',
                                  'ic' => '8.1789193328484',
                                  'sr' => '7.65917136766606',
                                  'vo' => '8.68372406230387',
                                  'fj' => '1.6094379124341',
                                  'py' => '4.84418708645859',
                                  'pm' => '4.43081679884331',
                                  "\x{153}i" => '4.0943445622221',
                                  'nm' => '7.4730690880322',
                                  'sd' => '9.15048420482282',
                                  'cj' => '3.46573590279973',
                                  'ei' => '8.33038156934942',
                                  'ha' => '8.27435700675629',
                                  'fb' => '2.07944154167984',
                                  'lg' => '6.46769872610435',
                                  'fq' => '3.58351893845611',
                                  'gh' => '4.61512051684126',
                                  'bc' => '2.89037175789616',
                                  'mr' => '6.46302945692067',
                                  'jc' => '3.78418963391826',
                                  'rm' => '8.20357773693795',
                                  'kn' => '2.39789527279837',
                                  'rn' => '7.38770923908104',
                                  'kb' => '2.77258872223978',
                                  'ym' => '5.33753807970132',
                                  'uh' => '5.01063529409626',
                                  'vd' => '3.95124371858143',
                                  'xe' => '6.36818718635049',
                                  'zj' => '3.61091791264422',
                                  'mg' => '2.89037175789616',
                                  'ux' => '8.30276158070405',
                                  'db' => '5.19295685089021',
                                  'ob' => '6.94601399109923',
                                  'oa' => '4.77912349311153',
                                  'ru' => '7.91571319938212',
                                  'wy' => '1.6094379124341',
                                  'ku' => '1.6094379124341',
                                  "x\x{153}" => '1.09861228866811',
                                  'lo' => '8.31287139434261',
                                  'mz' => '0.693147180559945',
                                  'lb' => '6.90675477864855',
                                  'ml' => '5.78074351579233',
                                  'bj' => '4.83628190695148',
                                  'rv' => '7.30720231476474',
                                  'zp' => '5.21493575760899',
                                  'xf' => '4.65396035015752',
                                  'mf' => '3.17805383034795',
                                  'pr' => '9.09492952046486',
                                  'ap' => '8.62209360124161',
                                  'nf' => '7.34987370473834',
                                  'di' => '8.81433042263877',
                                  'uw' => '3.04452243772342',
                                  'ip' => '7.28069719538474',
                                  'zd' => '4.99721227376411',
                                  'kl' => '1.79175946922805',
                                  'bs' => '6.12468339089421',
                                  'we' => '4.47733681447821',
                                  'to' => '8.79300509129753',
                                  'ol' => '7.74975340627444',
                                  'cu' => '7.61579107203583',
                                  'ch' => '8.99118884193151',
                                  'yu' => '3.52636052461616',
                                  'eu' => '9.58788600008621',
                                  'mu' => '6.57368016696065',
                                  'wa' => '7.13249755166004',
                                  'zf' => '3.36729582998647',
                                  'pl' => '8.67008593751938',
                                  'ay' => '6.8501261661455',
                                  'qs' => '0',
                                  'xp' => '6.5694814204143',
                                  'pe' => '8.83913175254611',
                                  'ds' => '7.27100853828099',
                                  'an' => '10.0458547938231',
                                  'ef' => '8.53934599605737',
                                  'ua' => '7.98241634682773',
                                  'oy' => '7.00488198971286',
                                  'tt' => '9.00196227286245',
                                  "m\x{153}" => '1.79175946922805',
                                  'ss' => '9.49114887548479',
                                  'or' => '8.91368482472529',
                                  'cc' => '6.86380339145295',
                                  'fs' => '5.06890420222023',
                                  'xh' => '4.31748811353631',
                                  'nw' => '3.97029191355212',
                                  'th' => '7.69848278788095',
                                  "u\x{153}" => '0',
                                  'er' => '10.0410296415546',
                                  'dc' => '6.58340922215876',
                                  'iz' => '4.20469261939097',
                                  'hc' => '4.06044301054642',
                                  'gn' => '7.41637847919293',
                                  'hr' => '5.98896141688986',
                                  'qa' => '0',
                                  'yh' => '2.30258509299405',
                                  'kd' => '1.09861228866811',
                                  'zi' => '3.3322045101752',
                                  'kc' => '3.13549421592915',
                                  'cv' => '3.78418963391826',
                                  'vc' => '4.11087386417331',
                                  'dp' => '6.51025834052315',
                                  'hw' => '2.07944154167984',
                                  'ws' => '3.61091791264422',
                                  'rg' => '7.33498187887181',
                                  'ad' => '7.79523492900217',
                                  'dy' => '4.64439089914137',
                                  'sz' => '2.30258509299405',
                                  'ja' => '7.64156444126097',
                                  'jn' => '1.79175946922805',
                                  "d\x{153}" => '4.23410650459726',
                                  'vp' => '3.13549421592915',
                                  'nl' => '7.35244110024358',
                                  'vs' => '4.21950770517611',
                                  'el' => '10.1169847267985',
                                  "n\x{153}" => '3.98898404656427',
                                  'ij' => '6.33682573114644',
                                  'hh' => '1.6094379124341',
                                  'gg' => '3.40119738166216',
                                  'eb' => '7.65254569269392',
                                  'mm' => '8.92930284224307',
                                  'sj' => '7.50988306115491',
                                  'hg' => '0.693147180559945',
                                  'my' => '5.0998664278242',
                                  'yd' => '4.7361984483945',
                                  "v\x{153}" => '1.38629436111989',
                                  'jj' => '1.94591014905531',
                                  'iv' => '7.92768504561578',
                                  'tn' => '7.07580886397839',
                                  'rt' => '8.92558733903028',
                                  'yk' => '2.484906649788',
                                  'co' => '9.40475517645752',
                                  'bo' => '7.51643330291563',
                                  'cy' => '4.15888308335967',
                                  'zo' => '4.52178857704904',
                                  'ck' => '3.89182029811063',
                                  'bv' => '0.693147180559945',
                                  'lw' => '3.04452243772342',
                                  'yw' => '4.0943445622221',
                                  'oi' => '9.19705247764925',
                                  'dm' => '6.7286286130847',
                                  'bu' => '6.03068526026126',
                                  'ls' => '7.84188592898462',
                                  'mv' => '4.57471097850338',
                                  'ri' => '9.07703752466176',
                                  'ky' => '2.89037175789616',
                                  'ti' => '9.37729445163902',
                                  'ka' => '4.14313472639153',
                                  'wc' => '2.07944154167984',
                                  'ue' => '9.82595835002689',
                                  'ze' => '5.45958551414416',
                                  'hu' => '5.97380961186926',
                                  'se' => '9.94010873599177',
                                  "\x{153}n" => '1.09861228866811',
                                  'lf' => '6.18001665365257',
                                  'iq' => '7.59387784460512',
                                  'xv' => '4.74493212836325',
                                  'kq' => '0',
                                  'ph' => '6.68835471394676',
                                  'dx' => '0',
                                  'no' => '8.79694389354174',
                                  'nh' => '6.07993319509559',
                                  'rb' => '6.22455842927536',
                                  'lv' => '6.00141487796115',
                                  'tf' => '7.15383380157884',
                                  'xt' => '5.98141421125448',
                                  'ln' => '6.98286275146894',
                                  'wh' => '4.52178857704904',
                                  'ox' => '3.13549421592915',
                                  'iy' => '3.49650756146648',
                                  'uj' => '6.63331843328038',
                                  'ab' => '8.03851202097681',
                                  'uu' => '6.5792512120101',
                                  'rz' => '3.09104245335832',
                                  'js' => '3.63758615972639',
                                  "r\x{153}" => '1.38629436111989',
                                  'li' => '8.76186337327473',
                                  'ql' => '1.09861228866811',
                                  'td' => '9.09963224999176',
                                  'yr' => '5.22035582507832',
                                  'oq' => '5.68697535633982',
                                  'gv' => '2.19722457733622',
                                  'fp' => '4.4188406077966',
                                  'vq' => '3.2188758248682',
                                  'pa' => '9.44801779306743',
                                  'am' => '8.52892411429194',
                                  'xg' => '3.98898404656427',
                                  'tv' => '6.96508034560141',
                                  'ee' => '8.8071726229167',
                                  'cd' => '5.99645208861902',
                                  'pk' => '0',
                                  'fy' => '4.21950770517611',
                                  'eo' => '7.57198844937744',
                                  'cp' => '4.70048036579242',
                                  'go' => '6.76619171466035',
                                  'mj' => '2.63905732961526',
                                  'as' => '9.04581943980773',
                                  'nz' => '3.40119738166216',
                                  'wr' => '3.17805383034795',
                                  'vr' => '7.35372233039963',
                                  'ae' => '5.4510384535657',
                                  'rs' => '9.04652648673797',
                                  'du' => '8.75352933651643',
                                  'cn' => '4.76217393479776',
                                  'jb' => '1.6094379124341',
                                  'ia' => '7.86249719723055',
                                  'mx' => '0',
                                  'sy' => '6.41345895716736',
                                  'qv' => '0',
                                  'df' => '5.74939298590825',
                                  'vi' => '8.40020983593042',
                                  'rh' => '4.91998092582813',
                                  'xn' => '4.47733681447821',
                                  'bm' => '3.04452243772342',
                                  'nr' => '7.1929342212158',
                                  'vb' => '1.38629436111989',
                                  'kw' => '2.484906649788',
                                  'gf' => '3.13549421592915',
                                  'al' => '8.79467340138342',
                                  'uf' => '6.78445706263764',
                                  'uz' => '2.484906649788',
                                  'cw' => '4.68213122712422',
                                  'ht' => '6.46769872610435',
                                  'nt' => '10.3386732620934',
                                  'pc' => '5.89989735358249',
                                  'mw' => '3.93182563272433',
                                  'yo' => '6.41345895716736',
                                  'xc' => '6.51323011091231',
                                  'wi' => '5.7268477475872',
                                  'gc' => '3.98898404656427',
                                  'yz' => '0.693147180559945',
                                  'gu' => '7.37086016653672',
                                  'lq' => '7.19443685110033',
                                  'wq' => '0',
                                  'xu' => '4.14313472639153',
                                  'dr' => '7.76302130901852',
                                  'ac' => '8.47345026846832',
                                  'yb' => '3.29583686600433',
                                  'sk' => '2.56494935746154',
                                  'oj' => '6.4393503711001',
                                  'vy' => '2.30258509299405',
                                  "c\x{153}" => '5.33271879326537',
                                  'ty' => '5.66296048013595',
                                  'qd' => '0.693147180559945',
                                  'yn' => '3.71357206670431',
                                  'qc' => '1.38629436111989',
                                  'ax' => '3.89182029811063',
                                  'vh' => '0.693147180559945',
                                  'kp' => '1.94591014905531',
                                  'bb' => '1.94591014905531',
                                  'xs' => '5.25749537202778',
                                  'nq' => '7.39694860262101',
                                  'et' => '9.8644868151864',
                                  'im' => '8.39840965542627',
                                  'vj' => '1.6094379124341',
                                  'en' => '10.5429438298982',
                                  'pj' => '3.49650756146648',
                                  'ed' => '9.60588981529697',
                                  'ui' => '9.53589609685605',
                                  'zu' => '4.45434729625351',
                                  'dl' => '6.36990098282823',
                                  'qm' => '2.94443897916644',
                                  'nn' => '8.73552518573323',
                                  'bn' => '3.63758615972639',
                                  'ix' => '5.87211778947542',
                                  'pz' => '0',
                                  'jt' => '5.62762111369064',
                                  'gp' => '4.29045944114839',
                                  'mb' => '7.71289096149013',
                                  'pu' => '7.43425738213314',
                                  'ar' => '9.48600046920064',
                                  'sm' => '8.26487826280175',
                                  'ny' => '6.30991827822652',
                                  'xj' => '4.46590811865458',
                                  'ww' => '3.87120101090789',
                                  "s\x{153}" => '4.68213122712422',
                                  'bl' => '8.27512163021651',
                                  'bd' => '2.89037175789616',
                                  'mc' => '5.19295685089021',
                                  'le' => '10.4527354938994',
                                  'rr' => '7.81561053203519',
                                  'xi' => '6.12905021006055',
                                  'nu' => '7.60489448081162',
                                  'if' => '7.47420480649612',
                                  'xd' => '6.41999492814714',
                                  'fe' => '7.5847730776122',
                                  'dk' => '1.38629436111989',
                                  'rq' => '7.60887062919126',
                                  'nc' => '8.96316024283373',
                                  'st' => '9.23785825801292',
                                  'hm' => '4.77068462446567',
                                  'ko' => '4.31748811353631',
                                  'ak' => '3.61091791264422',
                                  'oo' => '5.51745289646471',
                                  'nj' => '6.43615036836943',
                                  'gq' => '3.58351893845611',
                                  'fv' => '2.83321334405622',
                                  'ge' => '8.37447688921464',
                                  'lh' => '6.54821910276237',
                                  'va' => '9.07897805377936',
                                  'gr' => '7.92840602618053',
                                  'hy' => '4.97673374242057',
                                  'ms' => '5.8171111599632',
                                  'ys' => '6.34388043412633',
                                  'uc' => '7.87739718635329',
                                  'rc' => '8.43489794868941',
                                  'it' => '10.1884409054167',
                                  'wf' => '1.38629436111989',
                                  'rj' => '6.27476202124194',
                                  'sb' => '7.11395610956603',
                                  'ly' => '6.56385552653213',
                                  'lu' => '8.93208043810331',
                                  'zv' => '5.16478597392351',
                                  'dn' => '6.00388706710654',
                                  'ks' => '5.21493575760899',
                                  'pt' => '6.91373735065968',
                                  'il' => '9.5468126085974',
                                  'mh' => '2.30258509299405',
                                  'xq' => '6.28785856016178',
                                  'oz' => '2.19722457733622',
                                  'zn' => '3.61091791264422',
                                  'pf' => '3.52636052461616',
                                  'og' => '5.91889385427315',
                                  'ho' => '7.61035761831284',
                                  'tb' => '6.8134445995109',
                                  'zt' => '4.02535169073515',
                                  'jy' => '3.76120011569356',
                                  'wu' => '0',
                                  'ud' => '7.88419993367604',
                                  'ff' => '7.54908271081229',
                                  'vg' => '2.39789527279837',
                                  'sn' => '7.59940133341582',
                                  'yc' => '4.9416424226093',
                                  'yi' => '4.91998092582813',
                                  'qn' => '0',
                                  'hl' => '4.83628190695148',
                                  'ew' => '5.35658627467201',
                                  'au' => '9.25560050338105',
                                  'sl' => '8.861350110796',
                                  "\x{153}u" => '6.19236248947487',
                                  'us' => '9.49137540170617',
                                  'fn' => '2.63905732961526',
                                  'qt' => '0',
                                  'ye' => '6.77650699237218',
                                  'tq' => '8.3165447179294',
                                  'cm' => '5.25227342804663',
                                  'lk' => '1.6094379124341',
                                  'bq' => '0.693147180559945',
                                  'jg' => '1.09861228866811',
                                  'su' => '8.58802437217683',
                                  'sc' => '8.73921611506174',
                                  'nb' => '6.75576892198425',
                                  'lx' => '0',
                                  'yl' => '4.66343909411207',
                                  'az' => '4.0943445622221',
                                  'ec' => '9.58328228837879',
                                  'po' => '9.02159824737931',
                                  'aj' => '6.35262939631957',
                                  'aa' => '5.59098698051086',
                                  'ez' => '7.56164174558878',
                                  'eq' => '8.86742743852498',
                                  'ts' => '8.8206993992149',
                                  'fw' => '2.484906649788',
                                  'xl' => '5.33271879326537',
                                  'lr' => '5.85507192220243',
                                  'yq' => '3.49650756146648',
                                  'rp' => '7.87169266432365',
                                  'np' => '7.89766815072691',
                                  "h\x{153}" => '2.39789527279837',
                                  'do' => '8.27308133366583',
                                  'mp' => '8.29704514908183',
                                  'zl' => '5.75890177387728',
                                  'iu' => '5.71042701737487',
                                  'wg' => '2.99573227355399',
                                  'oh' => '4.70953020131233',
                                  'fd' => '4.81218435537242',
                                  'ni' => '8.32941678393932',
                                  'jq' => '1.09861228866811',
                                  'pw' => '2.77258872223978',
                                  'wb' => '2.07944154167984',
                                  'ej' => '8.21554741194707',
                                  'yx' => '0',
                                  'ld' => '6.75576892198425',
                                  'jd' => '3.40119738166216',
                                  'uk' => '1.94591014905531',
                                  'vf' => '0.693147180559945',
                                  'kf' => '2.07944154167984',
                                  'gw' => '3.46573590279973',
                                  'vl' => '4.45434729625351',
                                  'tp' => '8.85879510585745',
                                  'je' => '8.67385500142962',
                                  'kr' => '1.38629436111989',
                                  'fo' => '8.01532730902172',
                                  'yt' => '5.32300997913841',
                                  'sh' => '6.48768401848461',
                                  'zm' => '5.2257466737132',
                                  'zs' => '4.52178857704904',
                                  'io' => '8.60135049942296',
                                  'so' => '9.17211915915598',
                                  'cz' => '1.09861228866811',
                                  'lt' => '7.17625453201714',
                                  'qf' => '0.693147180559945',
                                  'be' => '8.03430693633949',
                                  'wp' => '1.38629436111989',
                                  'jr' => '2.484906649788',
                                  'op' => '7.23633934275434',
                                  'ur' => '9.78492921641199',
                                  'bp' => '3.55534806148941',
                                  'dt' => '6.80461452006262',
                                  'qo' => '0',
                                  'tw' => '3.55534806148941',
                                  'ce' => '9.64432814701755',
                                  'ev' => '8.70930004894499',
                                  'at' => '8.89316082873538',
                                  'pi' => '7.14045304310116',
                                  'tg' => '6.69332366826995',
                                  'cq' => '5.12396397940326',
                                  'ou' => '10.1178728621764',
                                  'te' => '10.046721720622',
                                  'ig' => '7.77904864492556',
                                  'ns' => '9.54136924893133',
                                  'jf' => '2.39789527279837',
                                  'hf' => '3.43398720448515',
                                  'fg' => '0.693147180559945'
                                },
                    'log_n' => {
                                 'w' => '7.7376162828579',
                                 'r' => '11.6585398137752',
                                 'a' => '11.8986911404575',
                                 'd' => '11.0996045808965',
                                 'x' => '8.71440336070394',
                                 'j' => '9.3637479186055',
                                 'y' => '8.64874763115654',
                                 'u' => '11.6610264536909',
                                 'h' => '9.61979750135388',
                                 'k' => '6.45519856334012',
                                 'g' => '9.69041808679339',
                                 "\x{153}" => '6.31535800152233',
                                 'f' => '9.86729026422424',
                                 't' => '11.7853390652907',
                                 'i' => '11.824504711784',
                                 'e' => '12.5089511648632',
                                 'n' => '11.7617523574533',
                                 'm' => '10.9693183516799',
                                 'v' => '10.3381877859126',
                                 's' => '11.8583149671918',
                                 'l' => '11.5094694999968',
                                 'p' => '10.8538124939532',
                                 'c' => '10.9031630933442',
                                 'b' => '9.67092477930543',
                                 'q' => '10.2168008213609',
                                 'z' => '7.68570306123455',
                                 'o' => '11.4311512591185'
                               },
                    'log_sigma_n' => '14.3823294837576'
                  },
          'de' => {
                    'log_sigma_n2' => '11.9900102138065',
                    'log_n2' => {
                                  'ne' => '7.43779512167193',
                                  'sp' => '5.59471137960184',
                                  'ki' => '4.46590811865458',
                                  'tr' => '6.26530121273771',
                                  'gl' => '5.6021188208797',
                                  'hn' => '6.49072353450251',
                                  'sf' => '4.93447393313069',
                                  'ro' => '6.12029741895095',
                                  'fc' => '2.63905732961526',
                                  'pv' => '0',
                                  'lz' => '4.02535169073515',
                                  'zr' => '1.09861228866811',
                                  'br' => '5.52545293913178',
                                  'yv' => '1.09861228866811',
                                  'hd' => '5.88887795833288',
                                  'tc' => '4.49980967033027',
                                  'xk' => '0',
                                  'ke' => '6.11809719804135',
                                  'bk' => '1.38629436111989',
                                  'wd' => '0',
                                  'zk' => '0.693147180559945',
                                  'cs' => '0',
                                  'ow' => '4.26267987704132',
                                  'bf' => '1.6094379124341',
                                  'km' => '2.83321334405622',
                                  'af' => '5.01063529409626',
                                  'of' => '5.39362754635236',
                                  'yg' => '1.79175946922805',
                                  'dh' => '4.30406509320417',
                                  'tm' => '6.18826412308259',
                                  'jm' => '0',
                                  'ct' => '5.26269018890489',
                                  'pg' => '2.484906649788',
                                  'ga' => '5.85793315448346',
                                  'oe' => '4.36944785246702',
                                  'ep' => '6.11368217983223',
                                  'ek' => '5.13579843705026',
                                  'lj' => '1.38629436111989',
                                  'pn' => '1.6094379124341',
                                  'mi' => '6.82979373751242',
                                  'sv' => '4.46590811865458',
                                  'ul' => '4.76217393479776',
                                  'fa' => '6.15060276844628',
                                  'za' => '4.02535169073515',
                                  'kt' => '5.07517381523383',
                                  'fh' => '4.81218435537242',
                                  'uy' => '1.6094379124341',
                                  'ai' => '4.63472898822964',
                                  'uv' => '3.43398720448515',
                                  've' => '6.04737217904628',
                                  'na' => '6.59304453414244',
                                  'gj' => '1.94591014905531',
                                  'ba' => '5.04985600724954',
                                  'ub' => '5.17614973257383',
                                  'rf' => '5.62401750618734',
                                  'kz' => '2.19722457733622',
                                  'ma' => '6.63987583382654',
                                  'in' => '7.97968130238774',
                                  'id' => '4.95582705760126',
                                  'si' => '7.08590146436561',
                                  'ft' => '5.7268477475872',
                                  'me' => '7.16703787691222',
                                  're' => '7.47420480649612',
                                  'dd' => '5.32300997913841',
                                  'om' => '5.50533153593236',
                                  'by' => '3.36729582998647',
                                  'fi' => '4.91998092582813',
                                  'gs' => '5.10594547390058',
                                  'ir' => '6.65157187358973',
                                  'wo' => '5.81413053182507',
                                  'tz' => '5.80211837537706',
                                  'dq' => '1.6094379124341',
                                  'uo' => '1.79175946922805',
                                  'ii' => '2.484906649788',
                                  'hv' => '4.4188406077966',
                                  'jo' => '1.6094379124341',
                                  'bi' => '5.64897423816121',
                                  'ry' => '3.3322045101752',
                                  'fl' => '5.37063802812766',
                                  'nk' => '5.92157841964382',
                                  'mn' => '4.12713438504509',
                                  'gd' => '4.76217393479776',
                                  'nv' => '4.96284463025991',
                                  'ot' => '5.2040066870768',
                                  'lc' => '4.83628190695148',
                                  'ah' => '5.23644196282995',
                                  'lm' => '4.30406509320417',
                                  'ag' => '6.03787091992214',
                                  'on' => '6.54678541076052',
                                  'cr' => '2.94443897916644',
                                  'sg' => '5.32787616878958',
                                  'kh' => '2.99573227355399',
                                  'ov' => '3.73766961828337',
                                  'vu' => '0.693147180559945',
                                  'dw' => '5.11799381241676',
                                  'ih' => '6.15060276844628',
                                  'hj' => '2.94443897916644',
                                  'rl' => '5.5683445037611',
                                  'eh' => '6.82979373751242',
                                  'gk' => '3.2188758248682',
                                  'ea' => '5.4380793089232',
                                  'gm' => '3.49650756146648',
                                  'bg' => '3.17805383034795',
                                  'aw' => '3.91202300542815',
                                  'gy' => '0.693147180559945',
                                  'sq' => '1.6094379124341',
                                  'ca' => '3.98898404656427',
                                  'zz' => '2.19722457733622',
                                  'pp' => '4.17438726989564',
                                  'xr' => '0',
                                  'zb' => '1.09861228866811',
                                  'dg' => '4.4188406077966',
                                  'hq' => '0.693147180559945',
                                  'rd' => '6.61204103483309',
                                  'fu' => '4.60517018598809',
                                  'es' => '7.69439280262942',
                                  'sw' => '5.6021188208797',
                                  'lp' => '3.49650756146648',
                                  'sa' => '6.07764224334903',
                                  'yf' => '2.77258872223978',
                                  'ie' => '7.7944112057266',
                                  'tl' => '4.7361984483945',
                                  'tj' => '3.71357206670431',
                                  'nd' => '7.97899637085411',
                                  'pd' => '0',
                                  'de' => '7.85593219971861',
                                  'un' => '7.4770384723197',
                                  'rk' => '5.74939298590825',
                                  'md' => '4.80402104473326',
                                  'fm' => '3.61091791264422',
                                  'cl' => '3.2188758248682',
                                  'wt' => '2.99573227355399',
                                  'up' => '3.87120101090789',
                                  'hz' => '4.52178857704904',
                                  'ib' => '5.0998664278242',
                                  'he' => '7.74413662762799',
                                  'zh' => '2.07944154167984',
                                  'ex' => '4.26267987704132',
                                  'yj' => '1.94591014905531',
                                  'dj' => '2.484906649788',
                                  'wn' => '3.25809653802148',
                                  'vt' => '1.6094379124341',
                                  'da' => '6.90575327631146',
                                  'ug' => '5.29330482472449',
                                  'ju' => '4.18965474202643',
                                  'ci' => '3.68887945411394',
                                  'zg' => '2.99573227355399',
                                  'yy' => '1.79175946922805',
                                  'hb' => '5.03695260241363',
                                  'ta' => '6.35610766069589',
                                  'gz' => '2.83321334405622',
                                  'rw' => '5.84932477994686',
                                  'hs' => '5.79909265446053',
                                  'll' => '6.73933662735717',
                                  'em' => '6.83087423464618',
                                  'mo' => '4.29045944114839',
                                  'ps' => '1.09861228866811',
                                  'av' => '3.91202300542815',
                                  'ao' => '0.693147180559945',
                                  'is' => '7.12849594568004',
                                  'qu' => '4.26267987704132',
                                  'ut' => '6.24997524225948',
                                  'ok' => '3.87120101090789',
                                  'mt' => '4.99043258677874',
                                  'gi' => '5.08140436498446',
                                  'la' => '6.28599809450886',
                                  'bh' => '2.30258509299405',
                                  'gb' => '3.25809653802148',
                                  'bt' => '5.03695260241363',
                                  'zc' => '2.19722457733622',
                                  'oc' => '5.92157841964382',
                                  'xm' => '0',
                                  'tx' => '0',
                                  'nx' => '0',
                                  'hp' => '2.99573227355399',
                                  'pb' => '0.693147180559945',
                                  'dv' => '3.76120011569356',
                                  'ng' => '7.04053639021596',
                                  'yp' => '3.13549421592915',
                                  'gt' => '5.84643877505772',
                                  'od' => '4.57471097850338',
                                  'hi' => '6.89365635460264',
                                  'eg' => '6.18001665365257',
                                  'ya' => '3.66356164612965',
                                  'um' => '6.10702288774225',
                                  'cb' => '0',
                                  'os' => '5.2040066870768',
                                  'ey' => '5.90808293816893',
                                  'fr' => '6.07304453410041',
                                  'tu' => '5.95583736946483',
                                  'ra' => '6.76849321164863',
                                  'sr' => '4.14313472639153',
                                  'ic' => '7.84306401669205',
                                  'vo' => '6.12249280951439',
                                  'fj' => '0.693147180559945',
                                  'py' => '3.40119738166216',
                                  'pm' => '1.09861228866811',
                                  'nm' => '6.36647044773144',
                                  'sd' => '5.67675380226828',
                                  'ei' => '7.9355873855892',
                                  'ha' => '6.77536609093639',
                                  'fb' => '2.56494935746154',
                                  'lg' => '4.76217393479776',
                                  'gh' => '3.87120101090789',
                                  'bc' => '3.49650756146648',
                                  'mr' => '3.3322045101752',
                                  'rm' => '6.13339804299665',
                                  'kn' => '4.61512051684126',
                                  'rn' => '6.38519439899773',
                                  'kb' => '2.19722457733622',
                                  'ym' => '3.89182029811063',
                                  'ik' => '2.94443897916644',
                                  'uh' => '4.71849887129509',
                                  'vd' => '0',
                                  'xe' => '3.89182029811063',
                                  'zj' => '0',
                                  'mg' => '4.76217393479776',
                                  'db' => '4.47733681447821',
                                  'ob' => '4.54329478227',
                                  'oa' => '3.17805383034795',
                                  'ru' => '5.99396142730657',
                                  'wy' => '0',
                                  'ku' => '4.30406509320417',
                                  'lo' => '4.99721227376411',
                                  'mz' => '3.46573590279973',
                                  'lb' => '4.84418708645859',
                                  'ml' => '4.48863636973214',
                                  'bj' => '0',
                                  'wl' => '2.63905732961526',
                                  'zp' => '0.693147180559945',
                                  'rv' => '4.96284463025991',
                                  'mf' => '3.95124371858143',
                                  'pr' => '5.59842195899838',
                                  'fk' => '0.693147180559945',
                                  'ap' => '4.14313472639153',
                                  'nf' => '5.92425579741453',
                                  'di' => '7.24351297466548',
                                  'uw' => '3.73766961828337',
                                  'zd' => '3.04452243772342',
                                  'ip' => '3.58351893845611',
                                  'kl' => '4.89783979995091',
                                  'bs' => '4.88280192258637',
                                  'we' => '6.75460409948796',
                                  'ol' => '5.99645208861902',
                                  'to' => '6.29526600143965',
                                  'cu' => '3.3322045101752',
                                  'yu' => '2.70805020110221',
                                  'ch' => '8.59637398929068',
                                  'eu' => '6.38350663488401',
                                  'mu' => '5.31811999384422',
                                  'wa' => '6.36818718635049',
                                  'zf' => '0.693147180559945',
                                  'pl' => '4.55387689160054',
                                  'ay' => '4.0943445622221',
                                  'xp' => '2.07944154167984',
                                  'ds' => '5.35658627467201',
                                  'pe' => '5.02388052084628',
                                  'an' => '7.26192709270275',
                                  'ua' => '4.17438726989564',
                                  'ef' => '5.98896141688986',
                                  'tt' => '6.05678401322862',
                                  'oy' => '2.70805020110221',
                                  'ss' => '6.26339826259162',
                                  'or' => '6.54965074223381',
                                  'cc' => '3.09104245335832',
                                  'fs' => '3.97029191355212',
                                  'nw' => '6.2363695902037',
                                  'th' => '6.7719355558396',
                                  'hk' => '4.18965474202643',
                                  'er' => '8.422882511945',
                                  'dc' => '3.63758615972639',
                                  'iz' => '2.56494935746154',
                                  'hc' => '3.04452243772342',
                                  'hr' => '6.74523634948436',
                                  'gn' => '4.59511985013459',
                                  'yh' => '2.484906649788',
                                  'kd' => '3.3322045101752',
                                  'zi' => '4.70953020131233',
                                  'kc' => '2.83321334405622',
                                  'hw' => '5.87493073085203',
                                  'dp' => '3.29583686600433',
                                  'ws' => '2.484906649788',
                                  'rg' => '6.44413125670044',
                                  'ad' => '5.04342511691925',
                                  'sz' => '4.55387689160054',
                                  'dy' => '1.94591014905531',
                                  'ja' => '4.44265125649032',
                                  'jn' => '1.79175946922805',
                                  'zw' => '4.31748811353631',
                                  'vz' => '0',
                                  'nl' => '5.36597601502185',
                                  'vs' => '0',
                                  'el' => '7.26892012819372',
                                  'kk' => '1.38629436111989',
                                  'hh' => '5.26269018890489',
                                  'gg' => '3.52636052461616',
                                  'eb' => '6.62804137617953',
                                  'mm' => '6.06378520868761',
                                  'sj' => '3.13549421592915',
                                  'my' => '0.693147180559945',
                                  'hg' => '5.01063529409626',
                                  'yd' => '4.49980967033027',
                                  'iv' => '4.00733318523247',
                                  'tn' => '5.37527840768417',
                                  'rt' => '6.48157712927643',
                                  'yk' => '1.38629436111989',
                                  'co' => '4.79579054559674',
                                  'bo' => '4.33073334028633',
                                  'zo' => '2.94443897916644',
                                  'ck' => '5.86078622346587',
                                  'bv' => '2.30258509299405',
                                  'yw' => '3.25809653802148',
                                  'lw' => '3.71357206670431',
                                  'oi' => '3.61091791264422',
                                  'bu' => '4.99721227376411',
                                  'dm' => '4.75359019110636',
                                  'ls' => '5.80513496891649',
                                  'mv' => '3.2188758248682',
                                  'ri' => '6.56385552653213',
                                  'ky' => '1.38629436111989',
                                  'ti' => '6.76041469108343',
                                  'ka' => '5.14749447681345',
                                  'ue' => '5.5683445037611',
                                  'wc' => '1.94591014905531',
                                  'ze' => '5.92692602597041',
                                  'hu' => '5.37527840768417',
                                  'se' => '7.22620901010067',
                                  'iq' => '1.38629436111989',
                                  'lf' => '4.20469261939097',
                                  'kv' => '1.79175946922805',
                                  'ph' => '6.44094654063292',
                                  'no' => '5.46806014113513',
                                  'rb' => '5.76519110278484',
                                  'nh' => '5.8348107370626',
                                  'lv' => '3.36729582998647',
                                  'tf' => '5.12989871492307',
                                  'ln' => '4.75359019110636',
                                  'xt' => '2.63905732961526',
                                  'wh' => '3.91202300542815',
                                  'ox' => '0',
                                  'uj' => '1.94591014905531',
                                  'ab' => '5.70044357339069',
                                  'uu' => '3.2188758248682',
                                  'rz' => '5.71373280550937',
                                  'li' => '6.8001700683022',
                                  'td' => '6.8596149036542',
                                  'yr' => '3.04452243772342',
                                  'gv' => '2.99573227355399',
                                  'fp' => '2.83321334405622',
                                  'pa' => '4.79579054559674',
                                  'am' => '5.55682806169954',
                                  'tv' => '5.04342511691925',
                                  'ee' => '5.75257263882563',
                                  'cd' => '2.484906649788',
                                  'pk' => '0',
                                  'cp' => '0',
                                  'fy' => '2.83321334405622',
                                  'eo' => '4.26267987704132',
                                  'go' => '4.62497281328427',
                                  'as' => '6.85540879860993',
                                  'nz' => '5.68697535633982',
                                  'mj' => '1.94591014905531',
                                  'wr' => '4.65396035015752',
                                  'ae' => '4.12713438504509',
                                  'rs' => '6.72982407048948',
                                  'du' => '6.30261897574491',
                                  'ia' => '3.71357206670431',
                                  'sy' => '2.39789527279837',
                                  'df' => '4.56434819146784',
                                  'vi' => '4.74493212836325',
                                  'rh' => '5.79605775076537',
                                  'bm' => '2.83321334405622',
                                  'nr' => '4.77068462446567',
                                  'bz' => '2.07944154167984',
                                  'kw' => '2.56494935746154',
                                  'gf' => '3.09104245335832',
                                  'al' => '6.69579891705849',
                                  'uf' => '6.12029741895095',
                                  'uz' => '3.17805383034795',
                                  'cw' => '3.29583686600433',
                                  'ht' => '7.1929342212158',
                                  'nt' => '6.55961523749324',
                                  'pc' => '0.693147180559945',
                                  'mw' => '4.38202663467388',
                                  'yo' => '4.69134788222914',
                                  'xc' => '1.6094379124341',
                                  'wi' => '6.79346613258001',
                                  'iw' => '1.6094379124341',
                                  'gc' => '2.30258509299405',
                                  'yz' => '1.94591014905531',
                                  'gu' => '5.44241771052179',
                                  'dr' => '5.47646355193151',
                                  'ac' => '6.22851100359118',
                                  'yb' => '2.30258509299405',
                                  'oj' => '4.52178857704904',
                                  'sk' => '4.33073334028633',
                                  'ty' => '3.63758615972639',
                                  'yn' => '4.06044301054642',
                                  'ax' => '2.30258509299405',
                                  'kp' => '1.38629436111989',
                                  'bb' => '2.07944154167984',
                                  'nq' => '2.19722457733622',
                                  'et' => '6.65027904858742',
                                  'im' => '5.8406416573734',
                                  'mk' => '3.95124371858143',
                                  'en' => '8.56274000637221',
                                  'ed' => '6.68586094706836',
                                  'ui' => '4.27666611901606',
                                  'zu' => '6.47389069635227',
                                  'dl' => '4.65396035015752',
                                  'nn' => '6.75460409948796',
                                  'bn' => '2.99573227355399',
                                  'ix' => '0.693147180559945',
                                  'pz' => '0.693147180559945',
                                  'gp' => '2.63905732961526',
                                  'pu' => '4.24849524204936',
                                  'mb' => '4.49980967033027',
                                  'fz' => '2.89037175789616',
                                  'ar' => '6.71174039505618',
                                  'sm' => '5.01727983681492',
                                  'ny' => '3.98898404656427',
                                  'xj' => '0',
                                  'ww' => '2.77258872223978',
                                  'bl' => '5.2257466737132',
                                  'bd' => '3.61091791264422',
                                  'mc' => '3.93182563272433',
                                  'le' => '7.38336814699238',
                                  'rr' => '5.54907608489522',
                                  'xi' => '1.6094379124341',
                                  'xd' => '0',
                                  'nu' => '6.50578406012823',
                                  'if' => '4.75359019110636',
                                  'fe' => '6.18414889093748',
                                  'rq' => '2.70805020110221',
                                  'dk' => '3.87120101090789',
                                  'nc' => '4.76217393479776',
                                  'st' => '7.88193748927207',
                                  'hm' => '5.92157841964382',
                                  'ko' => '5.05624580534831',
                                  'ak' => '2.99573227355399',
                                  'oo' => '3.73766961828337',
                                  'nj' => '4.12713438504509',
                                  'gq' => '0',
                                  'ge' => '7.61381868480863',
                                  'fv' => '1.94591014905531',
                                  'lh' => '3.66356164612965',
                                  'gr' => '5.70044357339069',
                                  'va' => '3.58351893845611',
                                  'hy' => '2.30258509299405',
                                  'ms' => '5.32300997913841',
                                  'ys' => '3.80666248977032',
                                  'uc' => '6.10702288774225',
                                  'rc' => '5.32787616878958',
                                  'wf' => '0',
                                  'it' => '6.78897174299217',
                                  'rj' => '3.63758615972639',
                                  'sb' => '4.84418708645859',
                                  'ly' => '3.55534806148941',
                                  'lu' => '5.48479693349065',
                                  'dn' => '4.70048036579242',
                                  'zv' => '2.19722457733622',
                                  'ks' => '4.63472898822964',
                                  'il' => '5.75890177387728',
                                  'pt' => '3.63758615972639',
                                  'mh' => '4.61512051684126',
                                  'zn' => '2.19722457733622',
                                  'oz' => '2.19722457733622',
                                  'kg' => '2.63905732961526',
                                  'pf' => '5.11198778835654',
                                  'og' => '4.55387689160054',
                                  'ho' => '5.71042701737487',
                                  'tb' => '4.93447393313069',
                                  'zt' => '4.66343909411207',
                                  'wu' => '3.93182563272433',
                                  'ud' => '5.28320372873799',
                                  'ff' => '4.95582705760126',
                                  'vg' => '1.38629436111989',
                                  'sn' => '5.01727983681492',
                                  'yc' => '2.56494935746154',
                                  'yi' => '3.63758615972639',
                                  'hl' => '6.21460809842219',
                                  'au' => '7.19967834569117',
                                  'sl' => '4.62497281328427',
                                  'ew' => '6.18414889093748',
                                  'us' => '6.76734312526539',
                                  'fn' => '3.91202300542815',
                                  'dz' => '3.73766961828337',
                                  'ye' => '4.34380542185368',
                                  'tq' => '1.09861228866811',
                                  'bw' => '2.56494935746154',
                                  'lk' => '3.85014760171006',
                                  'jg' => '0.693147180559945',
                                  'tk' => '4.29045944114839',
                                  'su' => '4.91265488573605',
                                  'sc' => '7.18614430452233',
                                  'nb' => '6.02586597382531',
                                  'yl' => '2.63905732961526',
                                  'az' => '3.09104245335832',
                                  'ec' => '6.04973345523196',
                                  'po' => '3.80666248977032',
                                  'ez' => '4.90527477843843',
                                  'aa' => '3.63758615972639',
                                  'eq' => '3.29583686600433',
                                  'ts' => '6.57646956904822',
                                  'fw' => '2.70805020110221',
                                  'lr' => '3.43398720448515',
                                  'rp' => '4.11087386417331',
                                  'np' => '4.43081679884331',
                                  'do' => '5.6937321388027',
                                  'mp' => '4.66343909411207',
                                  'zl' => '2.89037175789616',
                                  'wg' => '2.39789527279837',
                                  'iu' => '2.70805020110221',
                                  'oh' => '5.4249500174814',
                                  'fd' => '4.59511985013459',
                                  'ni' => '7.05531284333975',
                                  'pw' => '1.79175946922805',
                                  'wb' => '0.693147180559945',
                                  'ej' => '3.73766961828337',
                                  'ld' => '5.52545293913178',
                                  'uk' => '3.09104245335832',
                                  'kf' => '2.30258509299405',
                                  'gw' => '4.02535169073515',
                                  'vl' => '1.09861228866811',
                                  'tp' => '3.71357206670431',
                                  'kr' => '4.8283137373023',
                                  'je' => '5.30330490805908',
                                  'fo' => '5.21493575760899',
                                  'yt' => '3.52636052461616',
                                  'sh' => '5.10594547390058',
                                  'zm' => '1.6094379124341',
                                  'zs' => '2.19722457733622',
                                  'io' => '5.00394630594546',
                                  'so' => '6.4377516497364',
                                  'lt' => '6.18001665365257',
                                  'be' => '7.25347038268453',
                                  'wp' => '1.09861228866811',
                                  'op' => '6.02102334934953',
                                  'ur' => '6.26909628370626',
                                  'bp' => '1.09861228866811',
                                  'dt' => '4.69134788222914',
                                  'tw' => '5.75257263882563',
                                  'ce' => '4.56434819146784',
                                  'ev' => '4.65396035015752',
                                  'at' => '6.22653666928747',
                                  'pi' => '4.31748811353631',
                                  'tg' => '5.6937321388027',
                                  'ou' => '5.14749447681345',
                                  'te' => '7.77275271646874',
                                  'ig' => '5.96614673912369',
                                  'ns' => '7.22256601882217',
                                  'hf' => '4.49980967033027',
                                  'fg' => '3.3322045101752'
                                },
                    'log_n' => {
                                 'w' => '8.00235954625271',
                                 'r' => '9.30683167216494',
                                 'a' => '9.02485381183907',
                                 'd' => '8.94206869304423',
                                 'x' => '4.45434729625351',
                                 'j' => '5.90263333340137',
                                 'y' => '6.58202513889283',
                                 'u' => '8.77121506237538',
                                 'h' => '9.24445190160495',
                                 'k' => '7.45124168498768',
                                 'g' => '8.40782465436087',
                                 'f' => '7.99564360428727',
                                 't' => '9.28256800597306',
                                 'i' => '9.480214825778',
                                 'e' => '10.1169443382608',
                                 'n' => '9.62786579457671',
                                 'v' => '6.95368421087054',
                                 'm' => '8.52931937121408',
                                 's' => '9.25874951118387',
                                 'l' => '8.74608021735751',
                                 'p' => '7.49108759353488',
                                 'c' => '8.7645219095188',
                                 'b' => '8.01367414283268',
                                 'q' => '4.26267987704132',
                                 'z' => '7.32646561384032',
                                 'o' => '8.42463920980563'
                               },
                    'log_sigma_n' => '11.9900164196866'
                  },
          'it' => {
                    'log_sigma_n2' => '12.442531158005',
                    'log_n2' => {
                                  'ne' => '7.69256964806791',
                                  'sp' => '6.46302945692067',
                                  'gg' => '6.05208916892442',
                                  'mm' => '5.79301360838414',
                                  'eb' => '5.78996017089725',
                                  'ki' => '3.04452243772342',
                                  'tr' => '7.54274354536855',
                                  'sj' => '0.693147180559945',
                                  'gl' => '6.59578051396131',
                                  'hn' => '2.77258872223978',
                                  'hg' => '1.09861228866811',
                                  'my' => '0.693147180559945',
                                  'yd' => '2.56494935746154',
                                  'sf' => '4.89034912822175',
                                  'iv' => '6.93342302573071',
                                  'ro' => '7.61233683716775',
                                  'tn' => '3.78418963391826',
                                  'pv' => '0',
                                  'fc' => '2.63905732961526',
                                  'lz' => '3.68887945411394',
                                  'rt' => '6.53958595561767',
                                  'vv' => '4.30406509320417',
                                  'co' => '8.0040315078527',
                                  'yk' => '1.38629436111989',
                                  'br' => '5.66296048013595',
                                  'bo' => '5.41610040220442',
                                  'hd' => '2.07944154167984',
                                  'yv' => '0',
                                  'zo' => '4.8283137373023',
                                  'ck' => '2.30258509299405',
                                  'tc' => '4.36944785246702',
                                  'bv' => '0.693147180559945',
                                  'ke' => '2.99573227355399',
                                  'wd' => '0',
                                  'cs' => '2.30258509299405',
                                  'yw' => '2.70805020110221',
                                  'lw' => '1.6094379124341',
                                  'oi' => '7.09589322109753',
                                  'ow' => '3.55534806148941',
                                  'bu' => '4.85203026391962',
                                  'dm' => '2.19722457733622',
                                  'bf' => '0',
                                  'km' => '0',
                                  'of' => '6.29341927884648',
                                  'af' => '6.39692965521615',
                                  'yg' => '0',
                                  'mv' => '1.09861228866811',
                                  'ls' => '5.68697535633982',
                                  'dh' => '1.94591014905531',
                                  'ri' => '8.14960173573616',
                                  'tm' => '5.55295958492162',
                                  'ct' => '5.14166355650266',
                                  'ti' => '8.00736706798333',
                                  'pg' => '2.63905732961526',
                                  'ky' => '1.94591014905531',
                                  'oe' => '6.43615036836943',
                                  'ga' => '5.70711026474888',
                                  'ep' => '6.7696419768525',
                                  'ek' => '1.38629436111989',
                                  'ka' => '3.09104245335832',
                                  'ue' => '6.58340922215876',
                                  'wc' => '0.693147180559945',
                                  'pn' => '2.19722457733622',
                                  'mi' => '6.99576615630485',
                                  'ul' => '6.04737217904628',
                                  'sv' => '4.17438726989564',
                                  'ze' => '4.87519732320115',
                                  'hu' => '1.94591014905531',
                                  'fa' => '6.08449941307517',
                                  'za' => '6.42971947803914',
                                  'kt' => '1.79175946922805',
                                  'se' => '7.30518821539304',
                                  'fh' => '0',
                                  'lf' => '4.70048036579242',
                                  'ai' => '6.64898455002478',
                                  'iq' => '5.07517381523383',
                                  'uv' => '3.25809653802148',
                                  'xv' => '0',
                                  've' => '7.0647590277918',
                                  'na' => '7.56320059235807',
                                  'ba' => '5.85507192220243',
                                  'ph' => '2.99573227355399',
                                  'no' => '7.86441990499457',
                                  'ub' => '4.67282883446191',
                                  'rb' => '4.57471097850338',
                                  'lv' => '5.07517381523383',
                                  'nh' => '3.29583686600433',
                                  'tf' => '3.58351893845611',
                                  'rf' => '4.15888308335967',
                                  'ln' => '4.23410650459726',
                                  'xt' => '2.30258509299405',
                                  'wh' => '3.13549421592915',
                                  'ma' => '7.31521838975297',
                                  'ox' => '2.07944154167984',
                                  'in' => '8.15708378502887',
                                  'id' => '7.42356844425917',
                                  'si' => '7.71601526664259',
                                  'ft' => '4.02535169073515',
                                  're' => '8.13476078241865',
                                  'me' => '7.51425465281641',
                                  'om' => '7.13807303404435',
                                  'dd' => '4.31748811353631',
                                  'by' => '3.25809653802148',
                                  'fi' => '6.48616078894409',
                                  'ab' => '6.20050917404269',
                                  'gs' => '2.89037175789616',
                                  'uu' => '3.04452243772342',
                                  'ir' => '6.82979373751242',
                                  'rz' => '4.78749174278205',
                                  'li' => '7.91644286012226',
                                  'wo' => '4.40671924726425',
                                  'td' => '5.21493575760899',
                                  'dq' => '0',
                                  'tz' => '1.09861228866811',
                                  'uo' => '6.39859493453521',
                                  'cg' => '0.693147180559945',
                                  'yr' => '2.89037175789616',
                                  'ii' => '6.45204895443723',
                                  'oq' => '4.60517018598809',
                                  'fp' => '2.77258872223978',
                                  'gv' => '0',
                                  'pa' => '6.84587987526405',
                                  'hv' => '2.484906649788',
                                  'am' => '7.43897159239586',
                                  'tv' => '3.09104245335832',
                                  'jo' => '0',
                                  'bi' => '6.56526497003536',
                                  'ee' => '6.76734312526539',
                                  'ry' => '3.29583686600433',
                                  'uq' => '1.09861228866811',
                                  'cd' => '2.77258872223978',
                                  'fl' => '3.71357206670431',
                                  'nk' => '2.77258872223978',
                                  'eo' => '5.71042701737487',
                                  'cp' => '2.39789527279837',
                                  'fy' => '2.83321334405622',
                                  'go' => '5.74300318780948',
                                  'mn' => '2.30258509299405',
                                  'gd' => '2.484906649788',
                                  'nv' => '5.24174701505964',
                                  'as' => '7.49554194388426',
                                  'nz' => '6.10479323241498',
                                  'wr' => '1.79175946922805',
                                  'ot' => '6.73459165997295',
                                  'lc' => '5.7037824746562',
                                  'ae' => '6.35610766069589',
                                  'vr' => '4.21950770517611',
                                  'ah' => '3.46573590279973',
                                  'rs' => '6.22851100359118',
                                  'lm' => '5.80513496891649',
                                  'du' => '5.92157841964382',
                                  'cn' => '2.89037175789616',
                                  'ia' => '7.98480338973441',
                                  'ag' => '6.78445706263764',
                                  'on' => '8.33471162182092',
                                  'sy' => '2.484906649788',
                                  'df' => '2.484906649788',
                                  'cr' => '5.65599181081985',
                                  'vi' => '6.88653164253051',
                                  'sg' => '3.46573590279973',
                                  'rh' => '1.09861228866811',
                                  'nr' => '3.68887945411394',
                                  'ov' => '6.49223983502047',
                                  'bz' => '0.693147180559945',
                                  'dw' => '2.94443897916644',
                                  'vu' => '3.66356164612965',
                                  'kw' => '1.09861228866811',
                                  'gf' => '1.6094379124341',
                                  'al' => '8.10076824307173',
                                  'ih' => '3.09104245335832',
                                  'rl' => '5.3890717298165',
                                  'uf' => '3.78418963391826',
                                  'uz' => '4.8283137373023',
                                  'eh' => '3.68887945411394',
                                  'cw' => '3.29583686600433',
                                  'ht' => '4.07753744390572',
                                  'nt' => '8.04846874366888',
                                  'gk' => '0',
                                  'ea' => '7.10987946307227',
                                  'pc' => '1.6094379124341',
                                  'gm' => '2.07944154167984',
                                  'mw' => '2.484906649788',
                                  'yo' => '4.70048036579242',
                                  'xc' => '1.38629436111989',
                                  'wi' => '4.33073334028633',
                                  'iw' => '1.94591014905531',
                                  'gc' => '2.30258509299405',
                                  'gu' => '5.99146454710798',
                                  'bg' => '0',
                                  'lq' => '3.55534806148941',
                                  'aw' => '2.89037175789616',
                                  'dr' => '5.01063529409626',
                                  'gy' => '0.693147180559945',
                                  'ac' => '7.31121838441963',
                                  'ca' => '7.39756153552405',
                                  'sq' => '2.39789527279837',
                                  'pp' => '5.80814248998044',
                                  'zz' => '6.06145691892802',
                                  'xr' => '0',
                                  'dg' => '2.07944154167984',
                                  'yb' => '1.79175946922805',
                                  'oj' => '4.47733681447821',
                                  'sk' => '1.94591014905531',
                                  'hq' => '1.09861228866811',
                                  'rd' => '5.67675380226828',
                                  'ty' => '3.61091791264422',
                                  'fu' => '5.95064255258773',
                                  'yn' => '1.6094379124341',
                                  'ax' => '2.484906649788',
                                  'es' => '7.98344006300654',
                                  'sw' => '3.52636052461616',
                                  'lp' => '5.7268477475872',
                                  'kp' => '0.693147180559945',
                                  'bb' => '5.51745289646471',
                                  'sa' => '6.93049476595163',
                                  'yf' => '2.19722457733622',
                                  'xb' => '0',
                                  'nq' => '5.09375020080676',
                                  'et' => '7.34665516317654',
                                  'ie' => '7.3664451483276',
                                  'tl' => '4.15888308335967',
                                  'nd' => '7.18916773842032',
                                  'cf' => '1.09861228866811',
                                  'tj' => '0',
                                  'im' => '7.3132203870903',
                                  'en' => '8.1786387885907',
                                  'pd' => '0.693147180559945',
                                  'de' => '7.9912539298402',
                                  'ed' => '7.70796153183549',
                                  'un' => '7.30653139893951',
                                  'ui' => '5.95583736946483',
                                  'zu' => '3.3322045101752',
                                  'rk' => '4.55387689160054',
                                  'dl' => '2.07944154167984',
                                  'md' => '1.94591014905531',
                                  'fm' => '0.693147180559945',
                                  'cl' => '4.969813299576',
                                  'wt' => '1.94591014905531',
                                  'up' => '5.11198778835654',
                                  'nn' => '6.17170059741091',
                                  'bn' => '1.38629436111989',
                                  'vn' => '1.38629436111989',
                                  'ix' => '1.09861228866811',
                                  'ib' => '6.3261494731551',
                                  'he' => '7.28000825288419',
                                  'gp' => '2.39789527279837',
                                  'mb' => '5.4380793089232',
                                  'pu' => '5.64897423816121',
                                  'ex' => '2.99573227355399',
                                  'sm' => '5.65248918026865',
                                  'ar' => '7.92660259918138',
                                  'ny' => '3.98898404656427',
                                  'wn' => '2.56494935746154',
                                  'xj' => '0',
                                  'ww' => '2.77258872223978',
                                  'bl' => '4.62497281328427',
                                  'bd' => '0',
                                  'mc' => '2.63905732961526',
                                  'da' => '7.13648320859025',
                                  'le' => '7.90691548867859',
                                  'ug' => '4.86753445045558',
                                  'rr' => '6.25382881157547',
                                  'xi' => '1.79175946922805',
                                  'nu' => '6.1463292576689',
                                  'if' => '6.51025834052315',
                                  'xd' => '0',
                                  'ci' => '7.3185395485679',
                                  'fe' => '6.01859321449623',
                                  'yy' => '1.79175946922805',
                                  'rq' => '2.70805020110221',
                                  'hb' => '1.09861228866811',
                                  'dk' => '0',
                                  'ta' => '7.7944112057266',
                                  'nc' => '6.58340922215876',
                                  'gz' => '1.6094379124341',
                                  'rw' => '2.39789527279837',
                                  'hs' => '3.13549421592915',
                                  'll' => '7.92334821193015',
                                  'aq' => '5.08759633523238',
                                  'st' => '7.82164312623998',
                                  'hm' => '1.38629436111989',
                                  'ko' => '3.25809653802148',
                                  'em' => '7.06646697013696',
                                  'ak' => '2.77258872223978',
                                  'oo' => '5.4971682252932',
                                  'mo' => '7.4713630881871',
                                  'ps' => '2.484906649788',
                                  'ge' => '6.21260609575152',
                                  'fv' => '1.38629436111989',
                                  'lh' => '1.6094379124341',
                                  'av' => '6.78445706263764',
                                  'ao' => '4.94875989037817',
                                  'va' => '6.68336094576627',
                                  'gr' => '6.04025471127741',
                                  'is' => '7.87853419614036',
                                  'ut' => '6.85329909318608',
                                  'qu' => '6.80793494369993',
                                  'ok' => '2.99573227355399',
                                  'mt' => '2.83321334405622',
                                  'la' => '8.08641027532378',
                                  'gi' => '6.86484777797086',
                                  'hy' => '1.79175946922805',
                                  'ms' => '3.36729582998647',
                                  'ys' => '2.63905732961526',
                                  'gb' => '1.38629436111989',
                                  'bt' => '2.94443897916644',
                                  'uc' => '5.36597601502185',
                                  'oc' => '7.08422642209792',
                                  'zc' => '0',
                                  'rc' => '6.15697898558556',
                                  'tx' => '0',
                                  'it' => '7.64300363556072',
                                  'hp' => '2.70805020110221',
                                  'wf' => '0',
                                  'sb' => '3.78418963391826',
                                  'ly' => '3.61091791264422',
                                  'pb' => '0.693147180559945',
                                  'ng' => '6.19236248947487',
                                  'dv' => '1.09861228866811',
                                  'gt' => '4.40671924726425',
                                  'yp' => '2.99573227355399',
                                  'od' => '7.38647084882989',
                                  'lu' => '6.38012253689976',
                                  'dn' => '1.94591014905531',
                                  'il' => '7.58832367733522',
                                  'hi' => '6.55677835615804',
                                  'pt' => '2.99573227355399',
                                  'ks' => '3.87120101090789',
                                  'mh' => '0',
                                  'eg' => '6.74875954749168',
                                  'oz' => '3.91202300542815',
                                  'ya' => '3.61091791264422',
                                  'um' => '6.03548143252476',
                                  'og' => '6.62406522779989',
                                  'ho' => '4.31748811353631',
                                  'os' => '7.6251071482389',
                                  'cb' => '1.79175946922805',
                                  'tb' => '2.83321334405622',
                                  'fr' => '5.68697535633982',
                                  'ey' => '2.77258872223978',
                                  'tu' => '7.02908756414966',
                                  'ra' => '7.96935774201635',
                                  'ic' => '7.95120715647297',
                                  'sr' => '2.56494935746154',
                                  'vo' => '6.63987583382654',
                                  'ff' => '5.52146091786225',
                                  'ud' => '5.29330482472449',
                                  'py' => '3.40119738166216',
                                  'pm' => '1.09861228866811',
                                  'nm' => '4.74493212836325',
                                  'sn' => '3.17805383034795',
                                  'yc' => '2.77258872223978',
                                  'sd' => '3.66356164612965',
                                  'yi' => '3.13549421592915',
                                  'ei' => '7.29641326877392',
                                  'ha' => '5.29330482472449',
                                  'lg' => '5.03043792139244',
                                  'hl' => '3.13549421592915',
                                  'sl' => '3.78418963391826',
                                  'ew' => '4.02535169073515',
                                  'au' => '5.81413053182507',
                                  'us' => '6.41673228251233',
                                  'gh' => '4.56434819146784',
                                  'bc' => '1.38629436111989',
                                  'mr' => '1.6094379124341',
                                  'fn' => '0',
                                  'rm' => '6.15697898558556',
                                  'ye' => '2.56494935746154',
                                  'tq' => '2.19722457733622',
                                  'kn' => '0',
                                  'rn' => '5.78689738136671',
                                  'kb' => '1.6094379124341',
                                  'cm' => '1.09861228866811',
                                  'ym' => '2.484906649788',
                                  'lk' => '0.693147180559945',
                                  'uh' => '1.09861228866811',
                                  'xe' => '2.484906649788',
                                  'mg' => '0.693147180559945',
                                  'su' => '6.73696695800186',
                                  'ux' => '1.6094379124341',
                                  'sc' => '6.79346613258001',
                                  'db' => '3.17805383034795',
                                  'ob' => '5.47646355193151',
                                  'oa' => '6.58892647753352',
                                  'ru' => '6.02102334934953',
                                  'wy' => '0.693147180559945',
                                  'nb' => '4.95582705760126',
                                  'yl' => '0',
                                  'ku' => '0',
                                  'az' => '6.23048144757848',
                                  'lo' => '7.24636808010246',
                                  'ec' => '7.50163445788341',
                                  'po' => '7.05703698169789',
                                  'aj' => '0',
                                  'lb' => '4.12713438504509',
                                  'aa' => '6.07993319509559',
                                  'ez' => '5.6937321388027',
                                  'eq' => '5.36597601502185',
                                  'ts' => '4.47733681447821',
                                  'ml' => '2.56494935746154',
                                  'bj' => '0',
                                  'rv' => '5.07517381523383',
                                  'fw' => '1.09861228866811',
                                  'xf' => '0',
                                  'mf' => '2.07944154167984',
                                  'xl' => '1.09861228866811',
                                  'pr' => '7.03174125876313',
                                  'lr' => '4.74493212836325',
                                  'ap' => '6.89871453432999',
                                  'nf' => '5.54907608489522',
                                  'rp' => '5.09375020080676',
                                  'di' => '8.09407314806935',
                                  'np' => '5.22035582507832',
                                  'uw' => '1.38629436111989',
                                  'ip' => '6.95844839329766',
                                  'zd' => '0',
                                  'do' => '7.06304816338817',
                                  'kl' => '1.09861228866811',
                                  'mp' => '6.53087762772588',
                                  'bs' => '2.07944154167984',
                                  'we' => '3.04452243772342',
                                  'iu' => '6.15697898558556',
                                  'wg' => '1.6094379124341',
                                  'ol' => '7.76429600645052',
                                  'to' => '7.76004068088038',
                                  'cu' => '5.92425579741453',
                                  'oh' => '3.76120011569356',
                                  'ch' => '7.5569505720129',
                                  'yu' => '1.79175946922805',
                                  'eu' => '5.79301360838414',
                                  'mu' => '5.80211837537706',
                                  'ni' => '7.50328963067508',
                                  'wa' => '3.52636052461616',
                                  'fd' => '1.6094379124341',
                                  'zf' => '0',
                                  'pw' => '1.79175946922805',
                                  'wb' => '0.693147180559945',
                                  'pl' => '5.73334127689775',
                                  'ay' => '3.76120011569356',
                                  'ej' => '0',
                                  'xp' => '2.07944154167984',
                                  'ld' => '5.04985600724954',
                                  'pe' => '7.10824413973154',
                                  'ds' => '3.04452243772342',
                                  'an' => '8.1341742721379',
                                  'ua' => '6.43133108193348',
                                  'ef' => '6.26339826259162',
                                  'uk' => '0.693147180559945',
                                  'kf' => '1.09861228866811',
                                  'gw' => '2.07944154167984',
                                  'vl' => '2.19722457733622',
                                  'tp' => '4.11087386417331',
                                  'je' => '4.47733681447821',
                                  'kr' => '0',
                                  'tt' => '7.43366654016617',
                                  'oy' => '2.94443897916644',
                                  'fo' => '6.52941883826223',
                                  'yt' => '2.89037175789616',
                                  'ss' => '7.28000825288419',
                                  'cc' => '6.77422388635761',
                                  'or' => '7.97762509878459',
                                  'sh' => '2.83321334405622',
                                  'io' => '7.8578675593318',
                                  'fs' => '1.09861228866811',
                                  'nw' => '2.56494935746154',
                                  'zm' => '0.693147180559945',
                                  'th' => '5.95842469302978',
                                  'so' => '7.22256601882217',
                                  'dc' => '2.56494935746154',
                                  'er' => '8.27078101316267',
                                  'iz' => '5.70044357339069',
                                  'cz' => '1.38629436111989',
                                  'hc' => '2.484906649788',
                                  'lt' => '6.69208374250663',
                                  'gn' => '6.13556489108174',
                                  'hr' => '2.30258509299405',
                                  'be' => '6.20657592672493',
                                  'wp' => '1.38629436111989',
                                  'yh' => '1.09861228866811',
                                  'kd' => '0.693147180559945',
                                  'op' => '6.90274273715859',
                                  'zi' => '6.89972310728487',
                                  'ur' => '6.85118492749374',
                                  'vc' => '1.09861228866811',
                                  'cv' => '1.6094379124341',
                                  'kc' => '1.79175946922805',
                                  'bp' => '1.09861228866811',
                                  'dp' => '2.63905732961526',
                                  'hw' => '1.09861228866811',
                                  'dt' => '3.68887945411394',
                                  'tw' => '2.19722457733622',
                                  'ws' => '2.19722457733622',
                                  'ce' => '6.86484777797086',
                                  'rg' => '5.57594910314632',
                                  'ad' => '7.37400185935016',
                                  'dy' => '2.07944154167984',
                                  'ja' => '1.79175946922805',
                                  'ev' => '6.41836493593621',
                                  'at' => '7.87359778968554',
                                  'pi' => '6.95939851213398',
                                  'tg' => '4.58496747867057',
                                  'ou' => '5.8805329864007',
                                  'cq' => '3.36729582998647',
                                  'te' => '8.15737044118677',
                                  'ig' => '6.4831073514572',
                                  'vp' => '0.693147180559945',
                                  'nl' => '5.15329159449778',
                                  'ns' => '6.46146817635372',
                                  'hf' => '2.07944154167984',
                                  'el' => '8.23004431012611',
                                  'fg' => '0',
                                  'hh' => '0.693147180559945'
                                },
                    'log_n' => {
                                 'w' => '5.71702770140622',
                                 'r' => '9.7242412622591',
                                 'a' => '10.1503476304677',
                                 'd' => '9.1535583578772',
                                 'x' => '3.89182029811063',
                                 'j' => '4.55387689160054',
                                 'y' => '5.86078622346587',
                                 'u' => '9.01371703047137',
                                 'h' => '7.8808043446749',
                                 'k' => '5.18178355029209',
                                 'g' => '8.47052078321781',
                                 'f' => '8.09681747057232',
                                 't' => '9.76249985923515',
                                 'i' => '10.3019951800768',
                                 'e' => '10.2733600247189',
                                 'n' => '9.77616541396078',
                                 'm' => '8.97259066827261',
                                 'v' => '8.27180403115471',
                                 's' => '9.48865369442386',
                                 'l' => '9.70814154461942',
                                 'p' => '8.78844095740459',
                                 'c' => '9.30555963855712',
                                 'b' => '7.87054784450771',
                                 'q' => '6.80793494369993',
                                 'z' => '7.75362354655975',
                                 'o' => '10.0477177582074'
                               },
                    'log_sigma_n' => '12.4425351050904'
                  },
          'es' => {
                    'log_sigma_n2' => '14.2945179068017',
                    'log_n2' => {
                                  'ne' => '9.13010597926558',
                                  'sp' => '8.93287262193137',
                                  'ki' => '2.63905732961526',
                                  'tr' => '9.09268232850795',
                                  'gl' => '5.57972982598622',
                                  'hn' => '4.24849524204936',
                                  'xx' => '4.17438726989564',
                                  'sf' => '6.74993119378857',
                                  'ro' => '9.53589609685605',
                                  'fc' => '4.06044301054642',
                                  'lz' => '5.06259503302697',
                                  'vv' => '0.693147180559945',
                                  'zr' => '3.09104245335832',
                                  'br' => '8.37054761107475',
                                  'hd' => '3.3322045101752',
                                  'yv' => '6.36475075685191',
                                  'tc' => '4.69134788222914',
                                  'ke' => '2.77258872223978',
                                  'wd' => '0',
                                  'cs' => '5.28826703069454',
                                  'ji' => '4.46590811865458',
                                  'ow' => '3.3322045101752',
                                  'km' => '0',
                                  'af' => '7.17548971362422',
                                  'of' => '7.15617663748062',
                                  'yg' => '5.27299955856375',
                                  'dh' => '4.65396035015752',
                                  'tm' => '5.31320597904179',
                                  'jm' => '2.99573227355399',
                                  'ct' => '5.92157841964382',
                                  'pg' => '2.56494935746154',
                                  'oe' => '8.80432511256254',
                                  'ga' => '8.33710912956247',
                                  'ep' => '8.68862230704377',
                                  'lj' => '5.21493575760899',
                                  'zy' => '4.89783979995091',
                                  'ek' => '0',
                                  'mi' => '8.8427489162961',
                                  'pn' => '3.29583686600433',
                                  'ul' => '7.53955882930103',
                                  'sv' => '7.36137542897735',
                                  'mq' => '4.40671924726425',
                                  'fa' => '7.18841273649695',
                                  'za' => '8.06211758275474',
                                  'xo' => '1.09861228866811',
                                  'kt' => '1.38629436111989',
                                  'fh' => '0',
                                  'uy' => '6.98841318199959',
                                  'ai' => '6.95368421087054',
                                  'uv' => '6.71295620067707',
                                  've' => '8.71784570489492',
                                  'na' => '9.29771001811309',
                                  'gj' => '0',
                                  'ba' => '9.08239335764556',
                                  'ub' => '6.94505106372583',
                                  'rf' => '5.64190707093811',
                                  'ma' => '9.05567289196404',
                                  'in' => '9.31829751348127',
                                  'id' => '8.70201162840878',
                                  'si' => '9.03169206054852',
                                  'ft' => '3.93182563272433',
                                  'me' => '9.23376388691977',
                                  're' => '9.8068665139317',
                                  'dd' => '6.6682282484174',
                                  'om' => '9.05718919248201',
                                  'by' => '3.43398720448515',
                                  'fi' => '7.32383056620232',
                                  'vm' => '3.17805383034795',
                                  'gs' => '4.12713438504509',
                                  'ir' => '8.41516046585109',
                                  'wo' => '4.40671924726425',
                                  'dq' => '6.01126717440416',
                                  'uo' => '5.04342511691925',
                                  'cg' => '0.693147180559945',
                                  'ii' => '4.77068462446567',
                                  'hv' => '2.56494935746154',
                                  'xa' => '2.99573227355399',
                                  'jo' => '8.64874763115654',
                                  'bi' => '8.04430540699064',
                                  'ry' => '7.00306545878646',
                                  'uq' => '6.22059017009974',
                                  'fl' => '5.30330490805908',
                                  'nk' => '1.79175946922805',
                                  'mn' => '5.08140436498446',
                                  'gd' => '3.63758615972639',
                                  'nv' => '7.18841273649695',
                                  'ot' => '8.87780039388258',
                                  'lc' => '8.09712193091871',
                                  'ah' => '7.84031298332016',
                                  'lm' => '7.74022952476318',
                                  'zq' => '4.45434729625351',
                                  'ag' => '7.86095636487639',
                                  'on' => '9.91719319959224',
                                  'cr' => '7.45645455517621',
                                  'sg' => '6.6052979209482',
                                  'ov' => '7.46164039220858',
                                  'vu' => '7.39449310721904',
                                  'dw' => '2.89037175789616',
                                  'ih' => '5.37527840768417',
                                  'hj' => '0.693147180559945',
                                  'rl' => '8.17948018535889',
                                  'eh' => '8.28853445941392',
                                  'ea' => '9.07543660951138',
                                  'gm' => '2.77258872223978',
                                  'xy' => '1.09861228866811',
                                  'bg' => '0',
                                  'aw' => '2.77258872223978',
                                  'gy' => '2.63905732961526',
                                  'sq' => '8.5016733797582',
                                  'ca' => '9.35798421388875',
                                  'pp' => '3.09104245335832',
                                  'zz' => '0',
                                  'xr' => '0',
                                  'dg' => '4.48863636973214',
                                  'zb' => '2.99573227355399',
                                  'hq' => '2.63905732961526',
                                  'rd' => '8.51278348292754',
                                  'fu' => '7.69484807238461',
                                  'jh' => '1.09861228866811',
                                  'es' => '10.5978589833958',
                                  'sw' => '3.52636052461616',
                                  'lp' => '7.36770857237437',
                                  'sa' => '9.61400385813772',
                                  'yf' => '5.88887795833288',
                                  'ie' => '9.51369892381297',
                                  'tl' => '5.35658627467201',
                                  'nd' => '9.59865932124938',
                                  'tj' => '1.79175946922805',
                                  'cf' => '3.04452243772342',
                                  'pd' => '2.30258509299405',
                                  'de' => '10.4462187373131',
                                  'un' => '9.02881849535279',
                                  'rk' => '4.53259949315326',
                                  'md' => '4.46590811865458',
                                  'fm' => '1.09861228866811',
                                  'cl' => '6.39692965521615',
                                  'jp' => '2.70805020110221',
                                  'wt' => '1.94591014905531',
                                  'up' => '6.75693238924755',
                                  'hz' => '3.52636052461616',
                                  'vn' => '3.76120011569356',
                                  'ib' => '7.41336733569524',
                                  'he' => '7.80261806344267',
                                  'ex' => '5.23644196282995',
                                  'zh' => '3.46573590279973',
                                  'yj' => '4.36944785246702',
                                  'dj' => '4.77912349311153',
                                  'wn' => '2.07944154167984',
                                  'vt' => '0.693147180559945',
                                  'da' => '9.441610810502',
                                  'ug' => '6.4377516497364',
                                  'ju' => '6.86484777797086',
                                  'zg' => '4.57471097850338',
                                  'ci' => '9.13572457859539',
                                  'yy' => '5.61677109766657',
                                  'hb' => '3.93182563272433',
                                  'jl' => '3.40119738166216',
                                  'ta' => '9.58204184993154',
                                  'rw' => '2.39789527279837',
                                  'hs' => '4.29045944114839',
                                  'll' => '9.22098353207466',
                                  'aq' => '8.76201995356159',
                                  'em' => '8.9061223308843',
                                  'mo' => '9.07234187381889',
                                  'ps' => '4.63472898822964',
                                  'av' => '8.24617155985756',
                                  'ao' => '7.37713371283395',
                                  'is' => '8.72225423517968',
                                  'qu' => '10.3890261370752',
                                  'ut' => '6.68461172766793',
                                  'mt' => '4.17438726989564',
                                  'ok' => '2.83321334405622',
                                  'gi' => '6.7202201551353',
                                  'la' => '10.1046717524959',
                                  'bh' => '0',
                                  'bt' => '1.79175946922805',
                                  'gb' => '1.94591014905531',
                                  'zc' => '5.67675380226828',
                                  'oc' => '8.84937050375457',
                                  'xm' => '2.07944154167984',
                                  'tx' => '0',
                                  'hp' => '3.17805383034795',
                                  'nx' => '0',
                                  'pb' => '3.91202300542815',
                                  'dv' => '5.24174701505964',
                                  'ng' => '7.85243908535751',
                                  'gt' => '4.55387689160054',
                                  'yp' => '7.22402480828583',
                                  'od' => '9.44065812703839',
                                  'jv' => '1.09861228866811',
                                  'hi' => '7.46622755621548',
                                  'eg' => '8.24748200428569',
                                  'ya' => '8.31409733540581',
                                  'um' => '7.09754885061479',
                                  'cb' => '2.56494935746154',
                                  'os' => '10.349518622391',
                                  'fr' => '6.53958595561767',
                                  'ey' => '8.20275638165564',
                                  'tu' => '7.98344006300654',
                                  'ra' => '10.1208946819984',
                                  'sr' => '7.08086789669078',
                                  'ic' => '8.48817624234574',
                                  'vo' => '7.77106708606541',
                                  'py' => '3.40119738166216',
                                  'pm' => '1.09861228866811',
                                  'nm' => '7.56734567601324',
                                  'sd' => '8.94350613203724',
                                  'cj' => '0',
                                  'ei' => '6.99576615630485',
                                  'ha' => '9.12913031655064',
                                  'fb' => '2.484906649788',
                                  'lg' => '7.59438124255182',
                                  'gh' => '3.17805383034795',
                                  'bc' => '3.43398720448515',
                                  'mr' => '4.17438726989564',
                                  'jc' => '2.39789527279837',
                                  'rm' => '8.11731246160197',
                                  'kn' => '0',
                                  'rn' => '7.74370325817375',
                                  'kb' => '1.38629436111989',
                                  'ym' => '6.99209642741589',
                                  'uh' => '5.82304589548302',
                                  'vd' => '3.13549421592915',
                                  'xe' => '2.70805020110221',
                                  'zj' => '0',
                                  'mg' => '3.09104245335832',
                                  'ux' => '1.09861228866811',
                                  'db' => '4.11087386417331',
                                  'ob' => '7.85670679309584',
                                  'oa' => '8.57791192645094',
                                  'ru' => '7.11151211649616',
                                  'wy' => '0',
                                  'ku' => '0',
                                  'lo' => '9.53863641731322',
                                  'lb' => '6.72503364216684',
                                  'ml' => '4.48863636973214',
                                  'bj' => '2.56494935746154',
                                  'zp' => '4.14313472639153',
                                  'rv' => '6.84268328223842',
                                  'mf' => '1.79175946922805',
                                  'pr' => '8.27103686579295',
                                  'ap' => '8.68862230704377',
                                  'nf' => '7.05875815251866',
                                  'di' => '9.29761838008324',
                                  'uw' => '1.38629436111989',
                                  'zd' => '5.23110861685459',
                                  'ip' => '6.77536609093639',
                                  'kl' => '0',
                                  'we' => '3.04452243772342',
                                  'bs' => '4.14313472639153',
                                  'to' => '9.48660754161267',
                                  'ol' => '8.97714648480847',
                                  'cu' => '8.75731184693641',
                                  'yu' => '5.7268477475872',
                                  'ch' => '8.76826314537129',
                                  'eu' => '6.97447891102505',
                                  'mu' => '8.06463647577422',
                                  'wa' => '2.77258872223978',
                                  'zf' => '2.07944154167984',
                                  'pl' => '7.04577657687951',
                                  'ay' => '8.70682132339263',
                                  'xp' => '4.15888308335967',
                                  'pe' => '8.64944877053671',
                                  'ds' => '6.37331978957701',
                                  'an' => '10.0642449314142',
                                  'ua' => '8.32385113133882',
                                  'ef' => '7.27724772663148',
                                  'oy' => '8.73456008995299',
                                  'tt' => '4.97673374242057',
                                  'or' => '9.73020502039284',
                                  'ss' => '8.15507488781144',
                                  'cc' => '4.51085950651685',
                                  'fs' => '1.94591014905531',
                                  'xh' => '0',
                                  'nw' => '2.484906649788',
                                  'th' => '5.95583736946483',
                                  'er' => '10.2648266026017',
                                  'dc' => '5.30826769740121',
                                  'iz' => '6.38856140554563',
                                  'hc' => '3.58351893845611',
                                  'gn' => '6.8001700683022',
                                  'hr' => '3.13549421592915',
                                  'yh' => '6.16120732169508',
                                  'kd' => '0.693147180559945',
                                  'vc' => '2.07944154167984',
                                  'zi' => '1.38629436111989',
                                  'cv' => '1.38629436111989',
                                  'kc' => '1.6094379124341',
                                  'dp' => '5.26785815906333',
                                  'hw' => '0.693147180559945',
                                  'ws' => '2.19722457733622',
                                  'rg' => '6.72743172485086',
                                  'ad' => '9.96199228190869',
                                  'dy' => '5.93489419561959',
                                  'sz' => '3.73766961828337',
                                  'ja' => '7.6425241342329',
                                  'jn' => '3.80666248977032',
                                  'vp' => '1.6094379124341',
                                  'nl' => '8.41183267575841',
                                  'vs' => '4.23410650459726',
                                  'el' => '10.2321436079573',
                                  'ij' => '8.45914025996762',
                                  'hh' => '2.77258872223978',
                                  'eb' => '7.64491934495886',
                                  'mm' => '4.51085950651685',
                                  'sj' => '5.27299955856375',
                                  'hg' => '2.99573227355399',
                                  'my' => '3.98898404656427',
                                  'yd' => '7.70930833338587',
                                  'iv' => '6.92559519711047',
                                  'tn' => '6.07304453410041',
                                  'rt' => '8.40178233990491',
                                  'yk' => '1.09861228866811',
                                  'co' => '9.65400002588232',
                                  'bo' => '7.20934025660291',
                                  'cy' => '2.77258872223978',
                                  'zo' => '7.24279792279376',
                                  'ck' => '1.09861228866811',
                                  'bv' => '0.693147180559945',
                                  'lw' => '1.6094379124341',
                                  'yw' => '2.77258872223978',
                                  'oi' => '6.13556489108174',
                                  'bu' => '7.50714107972761',
                                  'dm' => '6.16961073249146',
                                  'ls' => '7.33236920592906',
                                  'mv' => '1.79175946922805',
                                  'ri' => '8.81522155592216',
                                  'ky' => '1.38629436111989',
                                  'ti' => '8.59987855803485',
                                  'ka' => '2.39789527279837',
                                  'wc' => '0.693147180559945',
                                  'ue' => '10.5304415103613',
                                  'ze' => '4.35670882668959',
                                  'hu' => '6.67076632084587',
                                  'jz' => '0',
                                  'se' => '9.92896034850916',
                                  'lf' => '6.00388706710654',
                                  'iq' => '6.14418563412565',
                                  'xv' => '3.36729582998647',
                                  'ph' => '2.99573227355399',
                                  'no' => '9.55732855032537',
                                  'lv' => '7.38461038317697',
                                  'rb' => '6.87523208727658',
                                  'nh' => '6.65157187358973',
                                  'tf' => '3.68887945411394',
                                  'xt' => '3.3322045101752',
                                  'ln' => '6.31173480915291',
                                  'wh' => '3.17805383034795',
                                  'iy' => '5.32300997913841',
                                  'ox' => '4.40671924726425',
                                  'uj' => '6.19236248947487',
                                  'ab' => '9.32625499657254',
                                  'uu' => '2.56494935746154',
                                  'rz' => '5.80211837537706',
                                  'js' => '3.04452243772342',
                                  'li' => '8.28526113406895',
                                  'td' => '5.21493575760899',
                                  'yr' => '5.92157841964382',
                                  'oq' => '8.87877607170755',
                                  'fp' => '2.70805020110221',
                                  'gv' => '1.09861228866811',
                                  'vq' => '1.38629436111989',
                                  'pa' => '9.01310820244647',
                                  'am' => '9.28804187964004',
                                  'tv' => '3.52636052461616',
                                  'ee' => '8.9005490139363',
                                  'cd' => '4.86753445045558',
                                  'fy' => '2.83321334405622',
                                  'eo' => '8.26590733415575',
                                  'cp' => '3.17805383034795',
                                  'go' => '8.27308133366583',
                                  'as' => '10.1636185559006',
                                  'nz' => '7.14913159855741',
                                  'mj' => '1.09861228866811',
                                  'wr' => '1.79175946922805',
                                  'ae' => '8.60355435706428',
                                  'vr' => '2.70805020110221',
                                  'rs' => '8.09925056179696',
                                  'du' => '7.52617891334615',
                                  'cn' => '4.69134788222914',
                                  'jb' => '0.693147180559945',
                                  'ia' => '8.52178264375005',
                                  'sy' => '8.41604600941128',
                                  'df' => '3.52636052461616',
                                  'vi' => '8.51036996606811',
                                  'rh' => '5.82600010738045',
                                  'bm' => '1.38629436111989',
                                  'xn' => '0',
                                  'nr' => '6.75693238924755',
                                  'vb' => '1.09861228866811',
                                  'kw' => '1.09861228866811',
                                  'gf' => '1.94591014905531',
                                  'al' => '9.92073790594266',
                                  'uf' => '5.17614973257383',
                                  'uz' => '5.54907608489522',
                                  'cw' => '3.29583686600433',
                                  'nt' => '9.7553934942914',
                                  'ht' => '4.33073334028633',
                                  'pc' => '3.43398720448515',
                                  'mw' => '2.484906649788',
                                  'yo' => '8.01862546504575',
                                  'xc' => '4.20469261939097',
                                  'wi' => '4.30406509320417',
                                  'gc' => '2.484906649788',
                                  'yz' => '2.07944154167984',
                                  'gu' => '8.277411998949',
                                  'lq' => '6.67582322163485',
                                  'dr' => '7.42117752859539',
                                  'ac' => '9.2398020821258',
                                  'yb' => '6.0591231955818',
                                  'sk' => '0',
                                  'oj' => '6.7945865808765',
                                  'vy' => '2.56494935746154',
                                  'ty' => '4.46590811865458',
                                  'yn' => '6.70563909486',
                                  'ax' => '2.30258509299405',
                                  'kp' => '0',
                                  'vh' => '0',
                                  'bb' => '1.38629436111989',
                                  'xs' => '1.09861228866811',
                                  'nq' => '8.36985260351753',
                                  'et' => '8.67641669696422',
                                  'im' => '8.15190987294091',
                                  'vj' => '0',
                                  'en' => '10.5199156626827',
                                  'pj' => '2.19722457733622',
                                  'ed' => '9.38681151509196',
                                  'ui' => '8.71800933084636',
                                  'zu' => '3.93182563272433',
                                  'dl' => '5.90808293816893',
                                  'nn' => '6.67708346124714',
                                  'bn' => '3.93182563272433',
                                  'ix' => '3.73766961828337',
                                  'jt' => '0',
                                  'gp' => '2.99573227355399',
                                  'mb' => '7.45182223652793',
                                  'pu' => '8.26487826280175',
                                  'ar' => '9.85050862774524',
                                  'sm' => '8.20521842639541',
                                  'ny' => '7.00033446027523',
                                  'ww' => '2.484906649788',
                                  'bl' => '7.44600149832412',
                                  'bd' => '3.66356164612965',
                                  'mc' => '3.8286413964891',
                                  'le' => '9.54086639341985',
                                  'rr' => '7.9168074909376',
                                  'xi' => '3.97029191355212',
                                  'if' => '6.26909628370626',
                                  'nu' => '7.49886973397693',
                                  'xd' => '2.99573227355399',
                                  'fe' => '7.09837563859079',
                                  'dk' => '0',
                                  'rq' => '7.95191138185419',
                                  'nc' => '9.07760865952222',
                                  'st' => '9.677402178301',
                                  'hm' => '3.09104245335832',
                                  'ko' => '2.83321334405622',
                                  'ak' => '1.94591014905531',
                                  'oo' => '6.87005341179813',
                                  'nj' => '5.62040086571715',
                                  'gq' => '2.56494935746154',
                                  'fv' => '1.09861228866811',
                                  'ge' => '6.86484777797086',
                                  'lh' => '6.18208490671663',
                                  'va' => '7.87511928104029',
                                  'gr' => '7.7591874385078',
                                  'hy' => '2.30258509299405',
                                  'ys' => '7.40000951716269',
                                  'ms' => '7.81681996576455',
                                  'uc' => '7.83280751652486',
                                  'rc' => '8.09803475617607',
                                  'wf' => '0',
                                  'it' => '7.78447323573647',
                                  'rj' => '4.87519732320115',
                                  'sb' => '6.75343791859778',
                                  'ly' => '6.11368217983223',
                                  'lu' => '7.47193207824512',
                                  'dn' => '6.10479323241498',
                                  'zv' => '2.63905732961526',
                                  'ks' => '3.80666248977032',
                                  'il' => '8.10107150311954',
                                  'pt' => '5.43372200355424',
                                  'mh' => '2.77258872223978',
                                  'xq' => '1.6094379124341',
                                  'zn' => '6.25958146406492',
                                  'oz' => '6.289715570909',
                                  'pf' => '2.07944154167984',
                                  'og' => '6.6682282484174',
                                  'ho' => '8.6438258423496',
                                  'tb' => '3.93182563272433',
                                  'zt' => '3.80666248977032',
                                  'jy' => '2.30258509299405',
                                  'ff' => '2.63905732961526',
                                  'ud' => '7.81601383915903',
                                  'vg' => '1.09861228866811',
                                  'sn' => '7.55276208421415',
                                  'yc' => '7.43248380791712',
                                  'yi' => '4.0943445622221',
                                  'hl' => '3.40119738166216',
                                  'ew' => '3.89182029811063',
                                  'au' => '7.77779262633883',
                                  'sl' => '8.24170315972982',
                                  'us' => '8.30498958014036',
                                  'fn' => '2.07944154167984',
                                  'ye' => '7.94307271727793',
                                  'dz' => '0.693147180559945',
                                  'tq' => '4.33073334028633',
                                  'cm' => '5.75574221358691',
                                  'lk' => '0',
                                  'bq' => '1.38629436111989',
                                  'jg' => '0',
                                  'su' => '8.87486763568805',
                                  'sc' => '8.85309383613849',
                                  'nb' => '6.60665018619822',
                                  'lx' => '2.70805020110221',
                                  'yl' => '7.36010397298915',
                                  'az' => '7.43307534889858',
                                  'ec' => '9.24782881638717',
                                  'po' => '9.27058845232154',
                                  'aj' => '7.13807303404435',
                                  'ez' => '7.34148385236316',
                                  'aa' => '8.51016857647927',
                                  'eq' => '8.12355783506165',
                                  'ts' => '5.8636311755981',
                                  'fw' => '1.09861228866811',
                                  'xl' => '3.04452243772342',
                                  'yq' => '6.92461239604856',
                                  'lr' => '6.71295620067707',
                                  'rp' => '7.28000825288419',
                                  'np' => '7.63240112660145',
                                  'do' => '9.98585064296125',
                                  'mp' => '7.78113850984502',
                                  'zl' => '4.85981240436167',
                                  'iu' => '5.39816270151775',
                                  'wg' => '1.6094379124341',
                                  'oh' => '7.77779262633883',
                                  'fd' => '1.94591014905531',
                                  'ni' => '8.28273588020175',
                                  'jq' => '1.6094379124341',
                                  'pw' => '1.38629436111989',
                                  'wb' => '0.693147180559945',
                                  'ej' => '7.71735127218533',
                                  'ld' => '7.77106708606541',
                                  'jd' => '3.49650756146648',
                                  'vf' => '0',
                                  'kf' => '0.693147180559945',
                                  'gw' => '2.07944154167984',
                                  'vl' => '3.95124371858143',
                                  'tp' => '4.49980967033027',
                                  'je' => '7.34213173058472',
                                  'kr' => '0',
                                  'fo' => '6.4425401664682',
                                  'yt' => '6.8330317327862',
                                  'sh' => '7.52240023138712',
                                  'zm' => '4.06044301054642',
                                  'zs' => '4.35670882668959',
                                  'io' => '8.42090253109795',
                                  'so' => '8.94689552388845',
                                  'cz' => '2.89037175789616',
                                  'lt' => '7.68248244653451',
                                  'be' => '8.02387999273488',
                                  'wp' => '0',
                                  'jr' => '3.78418963391826',
                                  'op' => '8.57960445153763',
                                  'bp' => '1.6094379124341',
                                  'ur' => '8.1318247850072',
                                  'dt' => '4.92725368515721',
                                  'tw' => '2.07944154167984',
                                  'ce' => '8.87094386383772',
                                  'ev' => '8.35514473946184',
                                  'at' => '8.52257866369258',
                                  'tg' => '4.59511985013459',
                                  'pi' => '7.53636393840451',
                                  'cq' => '2.07944154167984',
                                  'ou' => '6.53813982376767',
                                  'te' => '9.66959897968574',
                                  'ig' => '8.0507033814703',
                                  'ns' => '8.51458980554612',
                                  'jf' => '1.6094379124341',
                                  'hf' => '2.63905732961526'
                                },
                    'log_n' => {
                                 'w' => '5.605802066296',
                                 'r' => '11.533962624036',
                                 'a' => '12.1775034035124',
                                 'd' => '11.3825547863082',
                                 'x' => '6.00881318544259',
                                 'j' => '9.2711532113727',
                                 'y' => '10.1441959350298',
                                 'u' => '11.2736144212438',
                                 'h' => '9.92510226250854',
                                 'k' => '4.89034912822175',
                                 'g' => '9.77792432956078',
                                 'f' => '8.98306328938037',
                                 't' => '11.0553720096617',
                                 'i' => '11.2739192644425',
                                 'e' => '12.3186421141337',
                                 'n' => '11.603606766209',
                                 'm' => '10.7149509599141',
                                 'v' => '9.79673718258925',
                                 's' => '11.7479264383736',
                                 'l' => '11.4034453643514',
                                 'p' => '10.4888824706018',
                                 'c' => '11.0028828678921',
                                 'q' => '10.3890261370752',
                                 'b' => '10.103444356875',
                                 'z' => '8.77847995250849',
                                 'o' => '11.9493141393985'
                               },
                    'log_sigma_n' => '14.2945185261995'
                  },
          'cz' => {
                    'log_sigma_n2' => '13.174830582489',
                    'log_n2' => {
                                  'ne' => '8.60483770126828',
                                  "i\x{148}" => '2.39789527279837',
                                  'sp' => '6.84906628263346',
                                  'ki' => '5.19849703126583',
                                  'tr' => '7.6182510978767',
                                  "\x{16f}\x{17e}" => '5.00394630594546',
                                  "\x{159}t" => '4.91265488573605',
                                  'gl' => '5.63121178182137',
                                  'hn' => '6.93731408122368',
                                  "v\x{161}" => '6.880384082186',
                                  "\x{11d}i" => '0',
                                  'sf' => '5.01727983681492',
                                  'ro' => '8.52595469708481',
                                  'pv' => '3.78418963391826',
                                  'fc' => '4.06044301054642',
                                  'lz' => '6.08449941307517',
                                  "\x{16f}n" => '3.66356164612965',
                                  'vv' => '4.84418708645859',
                                  "\x{11b}s" => '5.98393628068719',
                                  "\x{10d}j" => '3.85014760171006',
                                  "\x{11b}l" => '7.34148385236316',
                                  'zr' => '5.40717177146012',
                                  'br' => '6.49677499018586',
                                  'hd' => '4.88280192258637',
                                  'yv' => '5.76519110278484',
                                  'tc' => '5.82008293035236',
                                  'bk' => '3.13549421592915',
                                  'ke' => '6.1527326947041',
                                  'wd' => '1.94591014905531',
                                  'zk' => '5.80211837537706',
                                  'cs' => '4.57471097850338',
                                  'ji' => '7.01391547481053',
                                  'ow' => '5.28826703069454',
                                  "\x{11b}i" => '2.30258509299405',
                                  'km' => '5.93489419561959',
                                  'bf' => '0',
                                  "\x{159}g" => '0.693147180559945',
                                  'of' => '6.90575327631146',
                                  'af' => '5.63121178182137',
                                  "\x{10f}\x{161}" => '0',
                                  "\x{165}v" => '3.25809653802148',
                                  "\x{10f}s" => '3.68887945411394',
                                  'yg' => '2.39789527279837',
                                  "f\x{10d}" => '0',
                                  'dh' => '4.91265488573605',
                                  "\x{165}d" => '2.56494935746154',
                                  'tm' => '6.8134445995109',
                                  "\x{10f}z" => '2.77258872223978',
                                  'ct' => '7.18765716411496',
                                  'jm' => '5.7037824746562',
                                  'pg' => '4.24849524204936',
                                  'oe' => '4.27666611901606',
                                  'ga' => '5.99396142730657',
                                  'ep' => '7.83478810738819',
                                  'ek' => '7.77317368048254',
                                  'zy' => '4.34380542185368',
                                  'lj' => '6.39526159811545',
                                  'pn' => '5.90263333340137',
                                  'mi' => '7.72929567431048',
                                  "\x{10f}k" => '3.29583686600433',
                                  'ul' => '6.34738920965601',
                                  'sv' => '6.82219739062049',
                                  "y\x{159}" => '4.34380542185368',
                                  "i\x{165}" => '1.94591014905531',
                                  'fa' => '6.4707995037826',
                                  'za' => '7.8995244720322',
                                  'xo' => '1.6094379124341',
                                  'kt' => '6.83733281468559',
                                  "\x{161}\x{16f}" => '0.693147180559945',
                                  "\x{11b}\x{17e}" => '5.18178355029209',
                                  'fh' => '2.39789527279837',
                                  "z\x{16f}" => '4.70953020131233',
                                  "\x{10d}\x{16f}" => '2.484906649788',
                                  'uy' => '0',
                                  'ai' => '5.91079664404053',
                                  'uv' => '6.52356230614951',
                                  've' => '7.51425465281641',
                                  'na' => '8.54655780004614',
                                  'gj' => '1.6094379124341',
                                  'ba' => '6.10255859461357',
                                  'ub' => '6.08221891037645',
                                  "e\x{161}" => '6.48920493132532',
                                  'rf' => '4.65396035015752',
                                  'kz' => '5.52545293913178',
                                  'ma' => '7.56216163122565',
                                  'in' => '8.27512163021651',
                                  "\x{165}k" => '2.19722457733622',
                                  'id' => '7.26262860097424',
                                  "d\x{148}" => '2.83321334405622',
                                  "\x{17e}\x{17e}" => '2.56494935746154',
                                  'si' => '7.46565531013406',
                                  'ft' => '5.92958914338989',
                                  "z\x{161}" => '3.29583686600433',
                                  're' => '7.70616297019958',
                                  'me' => '7.72929567431048',
                                  "s\x{10d}" => '3.52636052461616',
                                  'om' => '7.9402277651457',
                                  'dd' => '5.73334127689775',
                                  "t\x{17e}" => '4.62497281328427',
                                  'by' => '7.85049318087114',
                                  'vm' => '6.361302477573',
                                  'fi' => '5.54517744447956',
                                  'gs' => '4.11087386417331',
                                  'ir' => '6.4425401664682',
                                  "\x{159}j" => '3.52636052461616',
                                  "t\x{165}" => '0',
                                  'wo' => '6.35437004079735',
                                  'tz' => '5.4249500174814',
                                  "z\x{10d}" => '3.61091791264422',
                                  'uo' => '5.26269018890489',
                                  "\x{159}p" => '4.0943445622221',
                                  "\x{17e}h" => '3.80666248977032',
                                  'cg' => '0.693147180559945',
                                  "\x{11b}c" => '5.95583736946483',
                                  'ii' => '4.85203026391962',
                                  "\x{17e}t" => '5.37989735354046',
                                  "\x{159}z" => '3.71357206670431',
                                  'hv' => '6.06610809010375',
                                  "y\x{17e}" => '6.00635315960173',
                                  'jo' => '5.62040086571715',
                                  'bi' => '5.64190707093811',
                                  "\x{17e}v" => '4.98360662170834',
                                  'ry' => '6.63200177739563',
                                  'kj' => '5.69035945432406',
                                  "\x{17e}b" => '4.92725368515721',
                                  "\x{10f}m" => '3.61091791264422',
                                  'fl' => '3.95124371858143',
                                  'nk' => '6.70563909486',
                                  "\x{161}s" => '4.44265125649032',
                                  "o\x{165}" => '4.00733318523247',
                                  'mn' => '6.95368421087054',
                                  'nv' => '6.31535800152233',
                                  'gd' => '4.30406509320417',
                                  'lc' => '6.21060007702465',
                                  'ot' => '7.90801944463247',
                                  'ah' => '6.56244409369372',
                                  "\x{159}s" => '4.77068462446567',
                                  "\x{161}\x{165}" => '4.23410650459726',
                                  "\x{165}e" => '1.79175946922805',
                                  'lm' => '6.3919171133926',
                                  "\x{17e}a" => '4.56434819146784',
                                  "\x{16f}k" => '4.0943445622221',
                                  "t\x{10f}" => '0',
                                  'ag' => '6.16120732169508',
                                  'on' => '8.26049285657318',
                                  "\x{16d}p" => '1.6094379124341',
                                  'cr' => '4.82028156560504',
                                  "o\x{161}" => '5.64190707093811',
                                  "\x{16f}m" => '5.01727983681492',
                                  'sg' => '2.77258872223978',
                                  'kh' => '5.25227342804663',
                                  "\x{16d}d" => '2.70805020110221',
                                  "c\x{161}" => '1.94591014905531',
                                  "o\x{159}" => '5.99893656194668',
                                  "u\x{10d}" => '5.63835466933375',
                                  'ov' => '8.27078101316267',
                                  "\x{11b}v" => '5.6937321388027',
                                  'dw' => '4.83628190695148',
                                  'vu' => '5.6021188208797',
                                  "\x{148}r" => '1.38629436111989',
                                  "\x{16f}r" => '3.55534806148941',
                                  'ih' => '5.95324333428778',
                                  'hj' => '4.69134788222914',
                                  'rl' => '5.78996017089725',
                                  "\x{10d}i" => '6.41999492814714',
                                  'eh' => '6.82979373751242',
                                  "\x{148}d" => '2.19722457733622',
                                  "n\x{11b}" => '7.80220931624712',
                                  "\x{11d}a" => '0',
                                  'gk' => '0.693147180559945',
                                  'ea' => '7.14440718032114',
                                  'gm' => '1.09861228866811',
                                  "\x{16f}c" => '2.39789527279837',
                                  "\x{148}h" => '1.09861228866811',
                                  'xy' => '0',
                                  "g\x{10d}" => '1.09861228866811',
                                  'aw' => '4.80402104473326',
                                  'gy' => '3.2188758248682',
                                  'ca' => '5.92157841964382',
                                  'zz' => '3.55534806148941',
                                  'pp' => '5.40267738187228',
                                  "j\x{17e}" => '4.17438726989564',
                                  'xr' => '1.94591014905531',
                                  'zb' => '5.52942908751142',
                                  'dg' => '2.94443897916644',
                                  "\x{16d}e" => '0.693147180559945',
                                  "\x{161}v" => '4.29045944114839',
                                  "\x{161}\x{17e}" => '3.40119738166216',
                                  'rd' => '6.21060007702465',
                                  'fu' => '5.46383180502561',
                                  "\x{10d}p" => '3.87120101090789',
                                  'es' => '8.22844388300403',
                                  'jh' => '4.31748811353631',
                                  'sw' => '5.48063892334199',
                                  "\x{10f}h" => '1.94591014905531',
                                  'lp' => '6.66440902035041',
                                  "p\x{16f}" => '5.29330482472449',
                                  "\x{10d}v" => '3.63758615972639',
                                  'sa' => '6.90975328164481',
                                  "a\x{10f}" => '2.484906649788',
                                  'yf' => '4.48863636973214',
                                  "n\x{109}" => '0',
                                  'ie' => '6.19031540585315',
                                  "u\x{148}" => '0.693147180559945',
                                  'tl' => '6.33682573114644',
                                  "p\x{10d}" => '2.70805020110221',
                                  'nd' => '7.35372233039963',
                                  'tj' => '5.47646355193151',
                                  'cf' => '2.30258509299405',
                                  "\x{17e}g" => '1.79175946922805',
                                  "o\x{10f}" => '4.36944785246702',
                                  'pd' => '3.36729582998647',
                                  'de' => '7.76302130901852',
                                  "\x{159}o" => '3.58351893845611',
                                  'un' => '7.11069612297883',
                                  "\x{17e}j" => '5.31320597904179',
                                  "m\x{159}" => '4.66343909411207',
                                  'rk' => '6.79122146272619',
                                  "\x{159}i" => '7.22983877815125',
                                  "b\x{159}" => '5.13579843705026',
                                  "\x{16f}z" => '4.29045944114839',
                                  'md' => '5.70044357339069',
                                  'fm' => '3.04452243772342',
                                  'cl' => '5.24702407216049',
                                  'jp' => '4.62497281328427',
                                  'wt' => '3.89182029811063',
                                  'up' => '6.92264389147589',
                                  'hz' => '5.12989871492307',
                                  "b\x{161}" => '1.6094379124341',
                                  "\x{11b}a" => '5.02388052084628',
                                  'vn' => '6.64639051484773',
                                  'ib' => '6.54391184556479',
                                  "\x{17e}s" => '5.72031177660741',
                                  'he' => '7.79605797431612',
                                  "y\x{161}" => '5.4380793089232',
                                  'ex' => '4.95582705760126',
                                  "t\x{16f}" => '4.7361984483945',
                                  'zh' => '5.25227342804663',
                                  "\x{165}j" => '3.73766961828337',
                                  'yj' => '5.88887795833288',
                                  "y\x{10d}" => '4.82028156560504',
                                  'dj' => '4.63472898822964',
                                  "\x{161}k" => '5.7268477475872',
                                  "n\x{16f}" => '4.38202663467388',
                                  'wn' => '4.04305126783455',
                                  "\x{11b}k" => '6.37331978957701',
                                  "\x{16d}k" => '0.693147180559945',
                                  'vt' => '6.08904487544685',
                                  "\x{16f}l" => '4.83628190695148',
                                  "\x{148}\x{16f}" => '1.09861228866811',
                                  "\x{159}n" => '3.58351893845611',
                                  'da' => '7.42833319419081',
                                  'ju' => '4.40671924726425',
                                  'ug' => '4.06044301054642',
                                  'ci' => '7.01391547481053',
                                  "\x{148}c" => '0.693147180559945',
                                  'zg' => '0',
                                  'wk' => '1.09861228866811',
                                  "i\x{17e}" => '5.92425579741453',
                                  'yy' => '3.76120011569356',
                                  'hb' => '4.57471097850338',
                                  'jl' => '4.17438726989564',
                                  "\x{10d}o" => '4.18965474202643',
                                  'ta' => '8.40020983593042',
                                  "u\x{159}" => '4.66343909411207',
                                  'gz' => '1.79175946922805',
                                  'rw' => '4.63472898822964',
                                  "\x{11b}u" => '3.98898404656427',
                                  'hs' => '5.5683445037611',
                                  'll' => '6.98007594056176',
                                  "\x{10d}\x{10d}" => '1.09861228866811',
                                  "\x{161}a" => '5.64544689764324',
                                  'em' => '8.23190824356418',
                                  "\x{17e}r" => '3.63758615972639',
                                  'mo' => '7.10414409298753',
                                  'ps' => '5.53733426701854',
                                  "\x{165}h" => '2.56494935746154',
                                  'av' => '7.68248244653451',
                                  'ao' => '5.95064255258773',
                                  "h\x{165}" => '0.693147180559945',
                                  "f\x{16f}" => '0.693147180559945',
                                  'is' => '7.92443418488756',
                                  'ut' => '7.64156444126097',
                                  'qu' => '5.62401750618734',
                                  "c\x{159}" => '1.38629436111989',
                                  'ok' => '7.24708058458576',
                                  'mt' => '6.41836493593621',
                                  'la' => '8.33302993974291',
                                  'gi' => '5.01063529409626',
                                  "y\x{165}" => '4.70048036579242',
                                  "c\x{10d}" => '1.94591014905531',
                                  'bh' => '2.56494935746154',
                                  'bt' => '5.12396397940326',
                                  'gb' => '2.77258872223978',
                                  "\x{16d}s" => '1.79175946922805',
                                  'oc' => '6.91968384984741',
                                  "\x{161}i" => '6.09582456243222',
                                  'zc' => '4.33073334028633',
                                  'xm' => '0',
                                  "s\x{159}" => '1.79175946922805',
                                  'tx' => '2.07944154167984',
                                  "g\x{16f}" => '3.46573590279973',
                                  'hp' => '5.52146091786225',
                                  "\x{16f}d" => '4.61512051684126',
                                  'nx' => '0',
                                  "b\x{16f}" => '4.46590811865458',
                                  "p\x{161}" => '4.33073334028633',
                                  "\x{11b}g" => '0.693147180559945',
                                  "b\x{165}" => '0',
                                  "\x{148}i" => '0',
                                  'pb' => '1.6094379124341',
                                  'ng' => '6.7428806357919',
                                  'dv' => '6.72142570079064',
                                  'yp' => '6.4118182677099',
                                  'gt' => '6.22455842927536',
                                  'od' => '7.88720858581393',
                                  'jv' => '4.95582705760126',
                                  'hi' => '6.63987583382654',
                                  "l\x{148}" => '2.83321334405622',
                                  'eg' => '5.31320597904179',
                                  'ya' => '6.38519439899773',
                                  'um' => '6.56103066589657',
                                  "i\x{10f}" => '2.77258872223978',
                                  'os' => '7.97796809312855',
                                  'cb' => '3.3322045101752',
                                  "\x{11b}\x{10d}" => '4.44265125649032',
                                  "r\x{17e}" => '5.31811999384422',
                                  'fr' => '5.61677109766657',
                                  'ey' => '4.70953020131233',
                                  'tu' => '6.69208374250663',
                                  'ra' => '8.00034949532468',
                                  "\x{16f}p" => '4.06044301054642',
                                  'ic' => '7.58629630715272',
                                  'sr' => '5.06259503302697',
                                  'vo' => '7.28276117960559',
                                  "\x{17e}e" => '7.43543801981455',
                                  "\x{16d}g" => '0.693147180559945',
                                  "n\x{165}" => '0.693147180559945',
                                  'fj' => '1.09861228866811',
                                  'py' => '5.62401750618734',
                                  "e\x{159}" => '5.67332326717149',
                                  'pm' => '3.71357206670431',
                                  'nm' => '6.86589107488344',
                                  "\x{159}d" => '4.91265488573605',
                                  "\x{161}c" => '4.04305126783455',
                                  'sd' => '5.04342511691925',
                                  "\x{11b}b" => '4.27666611901606',
                                  "e\x{16d}" => '0',
                                  'ei' => '6.17170059741091',
                                  'cj' => '3.73766961828337',
                                  "z\x{148}" => '0',
                                  'ha' => '7.3362856600213',
                                  "k\x{17e}" => '4.66343909411207',
                                  "i\x{10d}" => '5.6937321388027',
                                  'lg' => '2.484906649788',
                                  "\x{161}\x{10d}" => '2.83321334405622',
                                  "\x{10f}b" => '3.09104245335832',
                                  'gh' => '5.65599181081985',
                                  "\x{159}\x{165}" => '0.693147180559945',
                                  'bc' => '3.43398720448515',
                                  'mr' => '5.73009978297357',
                                  'jc' => '4.91265488573605',
                                  'rm' => '6.42162226780652',
                                  'kn' => '6.70441435496411',
                                  'rn' => '6.70073110954781',
                                  "\x{10d}h" => '2.99573227355399',
                                  'kb' => '5.35185813347607',
                                  'ym' => '5.81413053182507',
                                  "\x{11b}\x{165}" => '1.79175946922805',
                                  'ik' => '7.08840877867539',
                                  'uh' => '6.20455776256869',
                                  'vd' => '5.93224518744801',
                                  'xe' => '3.73766961828337',
                                  'zj' => '4.38202663467388',
                                  "\x{11b}n" => '6.13556489108174',
                                  "j\x{10f}" => '4.12713438504509',
                                  'mg' => '1.38629436111989',
                                  "\x{148}a" => '3.13549421592915',
                                  'ux' => '1.09861228866811',
                                  'db' => '5.28320372873799',
                                  'ob' => '7.63867982387611',
                                  "\x{16d}r" => '2.07944154167984',
                                  'oa' => '6.12686918411419',
                                  'ru' => '6.88141130364254',
                                  'wy' => '1.94591014905531',
                                  "a\x{165}" => '4.64439089914137',
                                  'ku' => '6.99759598298193',
                                  'lo' => '8.17075142375753',
                                  "e\x{10d}" => '6.5366915975913',
                                  'mz' => '5.5683445037611',
                                  'lb' => '5.81413053182507',
                                  "r\x{16f}" => '4.66343909411207',
                                  "z\x{10f}" => '0',
                                  'ml' => '6.31535800152233',
                                  "\x{16d}j" => '0',
                                  'bj' => '4.85981240436167',
                                  "c\x{148}" => '0',
                                  'zp' => '6.01859321449623',
                                  "u\x{17e}" => '6.52356230614951',
                                  'rv' => '6.29156913955832',
                                  "\x{148}v" => '2.484906649788',
                                  "\x{10f}j" => '3.46573590279973',
                                  'mf' => '3.3322045101752',
                                  'pr' => '8.12415060330663',
                                  'ap' => '7.65254569269392',
                                  'fk' => '1.38629436111989',
                                  'nf' => '5.03695260241363',
                                  'di' => '7.52402141520612',
                                  "\x{161}o" => '3.76120011569356',
                                  'uw' => '3.43398720448515',
                                  'zd' => '6.15060276844628',
                                  'ip' => '6.81673588059497',
                                  'kl' => '7.18614430452233',
                                  'we' => '5.30826769740121',
                                  'bs' => '4.24849524204936',
                                  "\x{148}j" => '2.39789527279837',
                                  'ol' => '7.39264752072162',
                                  'to' => '8.5039052970893',
                                  'cu' => '4.67282883446191',
                                  "\x{165}g" => '0.693147180559945',
                                  "\x{109}i" => '0',
                                  'ch' => '8.51919119407891',
                                  'yu' => '4.99043258677874',
                                  'eu' => '6.30627528694802',
                                  'mu' => '7.28756064030972',
                                  'wa' => '4.58496747867057',
                                  'zf' => '1.6094379124341',
                                  "\x{159}m" => '4.66343909411207',
                                  "f\x{17e}" => '0',
                                  "\x{159}h" => '3.25809653802148',
                                  "\x{161}j" => '3.89182029811063',
                                  'pl' => '6.71417052990947',
                                  'ay' => '5.59098698051086',
                                  "j\x{161}" => '4.87519732320115',
                                  "t\x{159}" => '6.28599809450886',
                                  'xp' => '4.0943445622221',
                                  "\x{11b}j" => '6.32793678372919',
                                  'pe' => '6.76388490856244',
                                  'ds' => '6.1527326947041',
                                  'an' => '8.47010158388239',
                                  "\x{10f}r" => '1.79175946922805',
                                  "\x{11b}w" => '1.09861228866811',
                                  "\x{16f}i" => '1.09861228866811',
                                  'ef' => '6.6682282484174',
                                  'ua' => '6.36475075685191',
                                  'tt' => '6.56526497003536',
                                  'oy' => '4.66343909411207',
                                  "v\x{159}" => '5.31811999384422',
                                  'ss' => '6.60800062529609',
                                  'or' => '7.99429498641598',
                                  'cc' => '5.36597601502185',
                                  "\x{11b}h" => '5.79301360838414',
                                  "m\x{10d}" => '3.91202300542815',
                                  'fs' => '3.63758615972639',
                                  'nw' => '4.55387689160054',
                                  'th' => '7.95120715647297',
                                  "\x{161}r" => '3.04452243772342',
                                  'hk' => '4.90527477843843',
                                  'er' => '8.15478757276852',
                                  'dc' => '5.70044357339069',
                                  "d\x{159}" => '4.90527477843843',
                                  "\x{148}b" => '2.484906649788',
                                  "\x{11b}m" => '5.57972982598622',
                                  'iz' => '6.17586727010576',
                                  "\x{10f}v" => '3.25809653802148',
                                  'hc' => '5.4510384535657',
                                  "y\x{10f}" => '0',
                                  "e\x{13e}" => '0',
                                  'hr' => '6.55961523749324',
                                  'gn' => '3.95124371858143',
                                  "\x{16f}\x{10d}" => '2.56494935746154',
                                  "\x{161}t" => '6.59304453414244',
                                  "v\x{148}" => '1.38629436111989',
                                  'yh' => '5.59098698051086',
                                  'kd' => '7.20117088328168',
                                  'zi' => '5.44673737166631',
                                  'vc' => '5.71702770140622',
                                  'cv' => '4.33073334028633',
                                  'kc' => '5.40717177146012',
                                  'dp' => '5.98141421125448',
                                  "\x{148}u" => '2.70805020110221',
                                  "\x{11b}\x{148}" => '0.693147180559945',
                                  'hw' => '2.63905732961526',
                                  'ws' => '4.27666611901606',
                                  "\x{11b}p" => '5.48479693349065',
                                  'rg' => '6.87005341179813',
                                  'ad' => '7.68799716639302',
                                  'dy' => '7.0833878476253',
                                  'sz' => '4.0943445622221',
                                  'ja' => '7.19067603433221',
                                  'jn' => '5.89164421182577',
                                  "i\x{161}" => '5.55682806169954',
                                  "o\x{10d}" => '6.64509096950564',
                                  "d\x{11b}" => '7.16472037877186',
                                  'vz' => '6.17378610390194',
                                  'vp' => '5.72358510195238',
                                  'nl' => '5.61677109766657',
                                  "h\x{10d}" => '3.52636052461616',
                                  'vs' => '6.24804287450843',
                                  "\x{148}k" => '2.77258872223978',
                                  'el' => '8.14293601043227',
                                  'ij' => '6.54821910276237',
                                  'kk' => '5.16478597392351',
                                  'hh' => '4.55387689160054',
                                  "\x{16d}z" => '1.6094379124341',
                                  'gg' => '1.6094379124341',
                                  'eb' => '7.30586003268401',
                                  'mm' => '6.03787091992214',
                                  "c\x{16f}" => '4.14313472639153',
                                  "\x{16f}\x{161}" => '1.79175946922805',
                                  'sj' => '4.67282883446191',
                                  "u\x{16d}" => '0',
                                  'fx' => '0',
                                  'my' => '6.12249280951439',
                                  'hg' => '1.6094379124341',
                                  "p\x{159}" => '7.54591815120932',
                                  'yd' => '6.04737217904628',
                                  "r\x{159}" => '2.63905732961526',
                                  'iv' => '7.37400185935016',
                                  'jj' => '4.63472898822964',
                                  "\x{10d}g" => '1.09861228866811',
                                  'tn' => '6.91572344863131',
                                  "\x{161}\x{161}" => '3.36729582998647',
                                  "\x{10f}u" => '2.56494935746154',
                                  'rt' => '6.91274282049318',
                                  "\x{161}\x{148}" => '0',
                                  'co' => '7.50988306115491',
                                  'yk' => '6.06378520868761',
                                  "k\x{16f}" => '5.17048399503815',
                                  "m\x{161}" => '4.7361984483945',
                                  "d\x{10d}" => '3.89182029811063',
                                  'bo' => '7.27793857294566',
                                  'cy' => '5.67675380226828',
                                  'zo' => '5.86078622346587',
                                  "d\x{16f}" => '4.46590811865458',
                                  'ck' => '5.4380793089232',
                                  'bv' => '4.11087386417331',
                                  "k\x{10f}" => '0.693147180559945',
                                  'yw' => '4.67282883446191',
                                  'lw' => '3.58351893845611',
                                  'oi' => '4.18965474202643',
                                  "\x{159}w" => '1.09861228866811',
                                  'dm' => '5.70044357339069',
                                  "\x{17e}m" => '4.71849887129509',
                                  'bu' => '7.04838640872188',
                                  "s\x{165}" => '3.98898404656427',
                                  "m\x{16f}" => '5.39362754635236',
                                  "r\x{10d}" => '4.74493212836325',
                                  "\x{17e}\x{10d}" => '2.63905732961526',
                                  "p\x{10f}" => '0.693147180559945',
                                  'ls' => '7.27239839257005',
                                  'mv' => '6.12249280951439',
                                  "t\x{161}" => '4.36944785246702',
                                  'ri' => '7.20563517641036',
                                  'ky' => '6.51619307604296',
                                  'ti' => '8.08825472712243',
                                  "\x{148}\x{10d}" => '1.6094379124341',
                                  'ka' => '7.77569574991525',
                                  'ue' => '3.87120101090789',
                                  'wc' => '2.63905732961526',
                                  "s\x{148}" => '2.30258509299405',
                                  'ze' => '6.62273632394984',
                                  'hu' => '6.33859407820318',
                                  "\x{13e}v" => '0',
                                  "h\x{148}" => '2.07944154167984',
                                  'jz' => '6.46302945692067',
                                  "\x{159}k" => '5.05624580534831',
                                  "\x{11b}\x{161}" => '4.53259949315326',
                                  'se' => '8.68524677641249',
                                  "\x{10f}d" => '2.63905732961526',
                                  'lf' => '4.77912349311153',
                                  'kv' => '6.15697898558556',
                                  'xv' => '1.79175946922805',
                                  "\x{161}\x{159}" => '2.39789527279837',
                                  'ph' => '4.99043258677874',
                                  "\x{11b}\x{10f}" => '2.30258509299405',
                                  "h\x{10f}" => '0.693147180559945',
                                  'no' => '8.0245348716057',
                                  'nh' => '6.22455842927536',
                                  'rb' => '4.74493212836325',
                                  'lv' => '6.48616078894409',
                                  'tf' => '5.03695260241363',
                                  "t\x{11b}" => '7.12608727329912',
                                  'ln' => '6.90575327631146',
                                  'xt' => '3.80666248977032',
                                  "\x{11b}o" => '4.45434729625351',
                                  'wh' => '5.04342511691925',
                                  "\x{16f}o" => '2.70805020110221',
                                  'iy' => '1.09861228866811',
                                  'ox' => '2.19722457733622',
                                  "a\x{135}" => '0',
                                  "l\x{16f}" => '4.36944785246702',
                                  "\x{16f}j" => '5.39816270151775',
                                  'uj' => '6.45676965557216',
                                  'ab' => '7.09340462586877',
                                  'uu' => '4.55387689160054',
                                  "\x{165}r" => '1.09861228866811',
                                  "\x{161}n" => '5.04342511691925',
                                  'rz' => '5.50533153593236',
                                  "\x{16d}t" => '1.6094379124341',
                                  'js' => '7.16006920759613',
                                  'li' => '8.43858279083433',
                                  'td' => '5.75257263882563',
                                  "\x{10f}p" => '3.36729582998647',
                                  "\x{10d}n" => '6.18826412308259',
                                  'yr' => '6.28226674689601',
                                  "h\x{17e}" => '3.52636052461616',
                                  "p\x{148}" => '1.38629436111989',
                                  'fp' => '4.69134788222914',
                                  'gv' => '2.99573227355399',
                                  'pa' => '7.51752085060303',
                                  "u\x{10f}" => '3.46573590279973',
                                  "\x{11b}e" => '1.09861228866811',
                                  "\x{159}f" => '0',
                                  "\x{161}z" => '3.61091791264422',
                                  'am' => '7.37963215260955',
                                  'tv' => '6.73933662735717',
                                  "\x{16f}v" => '4.81218435537242',
                                  'ee' => '6.37161184723186',
                                  "\x{10d}b" => '3.25809653802148',
                                  "o\x{148}" => '4.30406509320417',
                                  "e\x{17e}" => '6.35262939631957',
                                  'cd' => '4.74493212836325',
                                  "\x{165}o" => '2.89037175789616',
                                  'pk' => '3.80666248977032',
                                  "t\x{148}" => '0.693147180559945',
                                  "\x{16f}a" => '4.34380542185368',
                                  "v\x{11b}" => '7.18614430452233',
                                  'fy' => '4.85203026391962',
                                  'eo' => '6.75343791859778',
                                  'cp' => '4.33073334028633',
                                  "\x{10f}o" => '2.19722457733622',
                                  "\x{16d}u" => '0',
                                  "\x{165}u" => '2.99573227355399',
                                  "n\x{159}" => '4.29045944114839',
                                  "\x{17e}z" => '4.39444915467244',
                                  'go' => '5.22035582507832',
                                  'nz' => '5.67675380226828',
                                  'as' => '7.82204400818562',
                                  'mj' => '5.70044357339069',
                                  "\x{161}e" => '7.11232744471091',
                                  'wr' => '3.73766961828337',
                                  'vr' => '6.38012253689976',
                                  'ae' => '4.0943445622221',
                                  "p\x{11b}" => '5.54907608489522',
                                  'rs' => '6.24610676548156',
                                  "\x{165}\x{161}" => '0.693147180559945',
                                  'du' => '6.62140565176413',
                                  'cn' => '5.44241771052179',
                                  'jb' => '4.0943445622221',
                                  "n\x{10d}" => '5.01727983681492',
                                  "\x{16f}\x{159}" => '2.07944154167984',
                                  "b\x{11b}" => '5.76832099579377',
                                  'ia' => '6.77764659363512',
                                  "\x{165}n" => '3.17805383034795',
                                  "u\x{161}" => '5.77765232322266',
                                  'sy' => '5.51342874616498',
                                  'cx' => '0',
                                  'df' => '4.36944785246702',
                                  'vi' => '7.26892012819372',
                                  'rh' => '5.3890717298165',
                                  'bm' => '2.56494935746154',
                                  'nr' => '5.11198778835654',
                                  "b\x{10d}" => '2.83321334405622',
                                  'vb' => '4.56434819146784',
                                  'bz' => '3.85014760171006',
                                  'kw' => '3.04452243772342',
                                  'gf' => '3.61091791264422',
                                  'al' => '8.71915396346254',
                                  "\x{16d}a" => '1.09861228866811',
                                  'uf' => '4.56434819146784',
                                  "\x{161}b" => '3.36729582998647',
                                  "\x{16d}m" => '0.693147180559945',
                                  'uz' => '5.90263333340137',
                                  "h\x{16f}" => '3.85014760171006',
                                  "\x{17e}k" => '5.70711026474888',
                                  "\x{11b}r" => '4.85203026391962',
                                  'cw' => '5.24174701505964',
                                  'nt' => '7.34665516317654',
                                  'ht' => '6.65286302935335',
                                  'pc' => '5.65599181081985',
                                  'vk' => '5.7037824746562',
                                  'mw' => '4.45434729625351',
                                  'yo' => '6.85646198459459',
                                  "o\x{17e}" => '6.75110146893676',
                                  'xc' => '3.3322045101752',
                                  "a\x{17e}" => '6.35610766069589',
                                  'wi' => '6.26909628370626',
                                  "\x{148}t" => '3.61091791264422',
                                  "v\x{10d}" => '4.74493212836325',
                                  'iw' => '0.693147180559945',
                                  'yz' => '5.47227067367148',
                                  'gc' => '3.89182029811063',
                                  'gu' => '6.60394382460047',
                                  "k\x{161}" => '3.91202300542815',
                                  'lq' => '5.29831736654804',
                                  "n\x{17e}" => '5.08140436498446',
                                  'xu' => '1.09861228866811',
                                  'dr' => '6.62671774924902',
                                  "z\x{159}" => '4.27666611901606',
                                  'ac' => '7.10002716662926',
                                  "j\x{16f}" => '1.94591014905531',
                                  "e\x{10f}" => '5.28826703069454',
                                  "\x{10d}\x{17e}" => '1.38629436111989',
                                  'yb' => '6.21260609575152',
                                  "s\x{17e}" => '2.56494935746154',
                                  "\x{165}p" => '2.89037175789616',
                                  'vy' => '7.27931883541462',
                                  'sk' => '6.96224346426621',
                                  'oj' => '7.86863689418417',
                                  'ty' => '6.65544035036765',
                                  "\x{165}i" => '1.38629436111989',
                                  'yn' => '6.27664348934164',
                                  "\x{159}\x{10d}" => '2.70805020110221',
                                  'ax' => '4.04305126783455',
                                  "\x{159}c" => '4.53259949315326',
                                  "\x{165}f" => '0',
                                  "\x{10d}c" => '3.93182563272433',
                                  "v\x{16f}" => '5.20948615284142',
                                  "x\x{159}" => '0',
                                  "\x{165}\x{17e}" => '3.13549421592915',
                                  "\x{148}m" => '2.07944154167984',
                                  "\x{10d}m" => '4.44265125649032',
                                  "r\x{165}" => '1.38629436111989',
                                  'vh' => '5.45958551414416',
                                  "\x{161}h" => '4.18965474202643',
                                  'kp' => '5.90536184805457',
                                  'bb' => '2.30258509299405',
                                  "\x{10d}\x{161}" => '1.79175946922805',
                                  'xs' => '0',
                                  "\x{161}p" => '5.01727983681492',
                                  'et' => '7.89319886954461',
                                  "\x{161}d" => '4.11087386417331',
                                  "\x{16f}u" => '2.07944154167984',
                                  "\x{16f}b" => '3.95124371858143',
                                  "\x{165}a" => '4.29045944114839',
                                  'im' => '6.8501261661455',
                                  "\x{11b}\x{159}" => '4.72738781871234',
                                  "e\x{165}" => '1.38629436111989',
                                  'mk' => '5.5834963087817',
                                  'en' => '8.71391062849392',
                                  'vj' => '4.7361984483945',
                                  'pj' => '3.25809653802148',
                                  "\x{16f}s" => '5.25227342804663',
                                  'ed' => '8.2776661608515',
                                  'ui' => '5.74620319054015',
                                  "\x{17e}\x{161}" => '4.43081679884331',
                                  'zu' => '5.34233425196481',
                                  "j\x{165}" => '0',
                                  "\x{165}s" => '3.80666248977032',
                                  'dl' => '6.93634273583405',
                                  "\x{135}o" => '0',
                                  "\x{159}e" => '7.71020519443253',
                                  "\x{17e}f" => '1.09861228866811',
                                  "h\x{159}" => '4.69134788222914',
                                  'nn' => '6.37672694789863',
                                  'bn' => '4.88280192258637',
                                  "l\x{161}" => '5.08140436498446',
                                  'ix' => '2.63905732961526',
                                  'jt' => '5.68017260901707',
                                  'pz' => '1.94591014905531',
                                  "\x{159}\x{161}" => '3.43398720448515',
                                  "\x{11b}f" => '3.3322045101752',
                                  'gp' => '4.39444915467244',
                                  'mb' => '5.47646355193151',
                                  'pu' => '5.82008293035236',
                                  'fz' => '0',
                                  'sm' => '7.04403289727469',
                                  'ar' => '7.67647364638916',
                                  "\x{10f}t" => '4.44265125649032',
                                  'ny' => '6.73459165997295',
                                  "f\x{159}" => '0',
                                  "\x{10f}c" => '1.79175946922805',
                                  "\x{10d}\x{148}" => '0',
                                  'ww' => '4.43081679884331',
                                  "\x{16d}l" => '1.09861228866811',
                                  'bl' => '6.21860011969173',
                                  "\x{161}m" => '4.66343909411207',
                                  'bd' => '3.97029191355212',
                                  "\x{17e}\x{159}" => '1.6094379124341',
                                  'mc' => '5.41610040220442',
                                  "\x{16d}c" => '0',
                                  "\x{16f}\x{148}" => '2.56494935746154',
                                  "\x{10f}a" => '3.25809653802148',
                                  'le' => '8.45871626165726',
                                  'rr' => '5.46383180502561',
                                  'xi' => '3.43398720448515',
                                  'nu' => '6.61873898351722',
                                  'if' => '5.76832099579377',
                                  "\x{10d}u" => '3.04452243772342',
                                  'xd' => '1.94591014905531',
                                  'fe' => '5.88332238848828',
                                  'dk' => '5.64190707093811',
                                  "\x{17e}u" => '3.93182563272433',
                                  "d\x{17e}" => '3.8286413964891',
                                  "\x{10d}r" => '2.39789527279837',
                                  "\x{165}\x{10d}" => '1.38629436111989',
                                  "\x{10d}a" => '5.61312810638807',
                                  'nc' => '6.87212810133899',
                                  "\x{10f}\x{17e}" => '1.09861228866811',
                                  "\x{165}b" => '2.484906649788',
                                  'st' => '8.77863395266279',
                                  'hm' => '5.53733426701854',
                                  'ko' => '7.98854298273769',
                                  "u\x{165}" => '2.07944154167984',
                                  'ak' => '8.10349427838097',
                                  'oo' => '6.22257626807137',
                                  "\x{11b}z" => '5.39816270151775',
                                  "\x{10f}l" => '1.6094379124341',
                                  'nj' => '5.64190707093811',
                                  "\x{17e}d" => '6.24027584517077',
                                  'ge' => '5.68017260901707',
                                  'fv' => '3.43398720448515',
                                  'lh' => '5.94803498918065',
                                  "m\x{148}" => '1.09861228866811',
                                  "\x{161}u" => '4.06044301054642',
                                  "l\x{10d}" => '5.11198778835654',
                                  "a\x{148}" => '3.55534806148941',
                                  'gr' => '6.02102334934953',
                                  'va' => '7.88532923927319',
                                  "g\x{159}" => '0',
                                  "a\x{159}" => '5.69035945432406',
                                  'hy' => '5.56068163101553',
                                  'ys' => '7.03702761468628',
                                  'ms' => '6.7945865808765',
                                  'uc' => '6.68710860786651',
                                  "\x{148}s" => '3.17805383034795',
                                  "\x{159}u" => '3.09104245335832',
                                  'rc' => '6.16541785423142',
                                  'it' => '7.91899248816525',
                                  "k\x{10d}" => '3.52636052461616',
                                  'wf' => '1.94591014905531',
                                  'rj' => '4.54329478227',
                                  'sb' => '5.18178355029209',
                                  "b\x{148}" => '0',
                                  'ly' => '6.62406522779989',
                                  "\x{16d}o" => '0.693147180559945',
                                  "y\x{148}" => '1.38629436111989',
                                  'lu' => '6.86901445066571',
                                  "\x{159}r" => '3.2188758248682',
                                  'zv' => '6.41017488196617',
                                  'dn' => '7.23128700432762',
                                  "v\x{17e}" => '5.55295958492162',
                                  'il' => '8.13094230223188',
                                  'ks' => '6.77536609093639',
                                  'pt' => '5.77144112313002',
                                  'mh' => '5.26785815906333',
                                  'zn' => '6.41673228251233',
                                  'oz' => '7.36073990305828',
                                  'pf' => '0',
                                  'kg' => '1.79175946922805',
                                  "\x{148}n" => '2.77258872223978',
                                  'og' => '4.84418708645859',
                                  'kx' => '0',
                                  'ho' => '8.09498875930377',
                                  'tb' => '5.605802066296',
                                  "\x{165}m" => '2.99573227355399',
                                  'zt' => '5.35658627467201',
                                  "i\x{159}" => '4.4188406077966',
                                  'wu' => '2.19722457733622',
                                  "\x{10d}e" => '6.91869521902047',
                                  "\x{16f}h" => '4.61512051684126',
                                  'ud' => '7.3004728142678',
                                  'ff' => '4.59511985013459',
                                  'xz' => '0',
                                  'vg' => '0',
                                  "\x{159}a" => '4.91265488573605',
                                  'sn' => '6.66440902035041',
                                  'yc' => '6.48920493132532',
                                  "\x{16d}i" => '0',
                                  'yi' => '5.18178355029209',
                                  "\x{148}o" => '3.91202300542815',
                                  "\x{17e}o" => '4.57471097850338',
                                  "a\x{16d}" => '4.21950770517611',
                                  'hl' => '7.66434663209862',
                                  "e\x{148}" => '4.02535169073515',
                                  'sl' => '7.22693601849329',
                                  'au' => '5.93753620508243',
                                  'ew' => '5.83773044716594',
                                  "\x{10d}l" => '5.04985600724954',
                                  'us' => '7.61085279039525',
                                  "\x{10f}f" => '0',
                                  'fn' => '2.83321334405622',
                                  'dz' => '4.51085950651685',
                                  'ye' => '4.33073334028633',
                                  "\x{10d}z" => '2.89037175789616',
                                  'cm' => '4.34380542185368',
                                  'jk' => '4.36944785246702',
                                  "s\x{16f}" => '3.68887945411394',
                                  "s\x{161}" => '2.94443897916644',
                                  "\x{16f}t" => '3.55534806148941',
                                  'lk' => '6.68085467879022',
                                  "o\x{11d}" => '0.693147180559945',
                                  "\x{161}l" => '5.80814248998044',
                                  "\x{11b}t" => '6.69579891705849',
                                  'jg' => '1.94591014905531',
                                  'tk' => '6.13988455222626',
                                  'su' => '6.03787091992214',
                                  'sc' => '5.93224518744801',
                                  "\x{159}l" => '4.20469261939097',
                                  "u\x{109}" => '0',
                                  "\x{10d}t" => '5.41610040220442',
                                  "\x{16f}f" => '0.693147180559945',
                                  "\x{16d}b" => '0',
                                  "l\x{10f}" => '0.693147180559945',
                                  'nb' => '6.81124437860129',
                                  "\x{165}l" => '1.6094379124341',
                                  'lx' => '0',
                                  'yl' => '7.05272104923232',
                                  'vw' => '0',
                                  "n\x{161}" => '4.70953020131233',
                                  'az' => '6.79570577517351',
                                  'po' => '8.26616443661249',
                                  'ec' => '7.95787735848981',
                                  'aj' => '7.20711885620776',
                                  'ez' => '7.26122509197192',
                                  'aa' => '6.36475075685191',
                                  'eq' => '4.34380542185368',
                                  "\x{165}\x{159}" => '1.09861228866811',
                                  "b\x{17e}" => '1.09861228866811',
                                  'ts' => '6.55677835615804',
                                  "\x{17e}n" => '5.85220247977447',
                                  "h\x{161}" => '2.70805020110221',
                                  'fw' => '3.04452243772342',
                                  "\x{165}c" => '1.38629436111989',
                                  "l\x{159}" => '3.71357206670431',
                                  "\x{159}v" => '4.57471097850338',
                                  'lr' => '5.40717177146012',
                                  "a\x{161}" => '6.27287700654617',
                                  'rp' => '5.5834963087817',
                                  "m\x{11b}" => '6.49978704065585',
                                  'np' => '6.49828214947643',
                                  "\x{10d}k" => '6.00635315960173',
                                  'do' => '8.20330402679528',
                                  'mp' => '6.63725803128446',
                                  'zl' => '5.82600010738045',
                                  'iu' => '5.77455154554441',
                                  'wg' => '3.55534806148941',
                                  'oh' => '7.36137542897735',
                                  "\x{10d}s" => '4.27666611901606',
                                  'ni' => '7.76004068088038',
                                  'fd' => '3.36729582998647',
                                  "\x{17e}i" => '6.30809844150953',
                                  "\x{148}f" => '0',
                                  'pw' => '3.3322045101752',
                                  'wb' => '2.70805020110221',
                                  "\x{17e}\x{148}" => '0.693147180559945',
                                  "k\x{159}" => '5.64897423816121',
                                  "\x{17e}\x{16f}" => '2.63905732961526',
                                  'ej' => '7.59287028784482',
                                  "\x{109}e" => '0',
                                  'ld' => '6.68835471394676',
                                  "d\x{161}" => '4.61512051684126',
                                  'jd' => '6.15697898558556',
                                  'uk' => '6.62140565176413',
                                  'kf' => '3.36729582998647',
                                  'vf' => '1.6094379124341',
                                  'gw' => '4.02535169073515',
                                  "\x{16d}n" => '1.09861228866811',
                                  'vl' => '6.57368016696065',
                                  'tp' => '6.16541785423142',
                                  "\x{159}\x{17e}" => '2.94443897916644',
                                  'je' => '8.33158624363075',
                                  'kr' => '6.83087423464618',
                                  "\x{10d}d" => '2.99573227355399',
                                  'fo' => '6.77308037565554',
                                  'yt' => '6.50876913697168',
                                  'sh' => '5.73009978297357',
                                  "r\x{148}" => '2.19722457733622',
                                  'io' => '7.16394668434255',
                                  'zm' => '5.5683445037611',
                                  'zs' => '4.49980967033027',
                                  "\x{148}g" => '0',
                                  "t\x{10d}" => '3.98898404656427',
                                  'so' => '7.15851399732932',
                                  "\x{16d}v" => '0.693147180559945',
                                  "l\x{17e}" => '5.6937321388027',
                                  "z\x{17e}" => '2.484906649788',
                                  'cz' => '3.68887945411394',
                                  'jx' => '0',
                                  'lt' => '6.58063913728495',
                                  'be' => '7.23777819192344',
                                  'wp' => '1.94591014905531',
                                  "\x{11b}d" => '6.05443934626937',
                                  'jr' => '4.02535169073515',
                                  'op' => '7.56216163122565',
                                  "\x{159}\x{16f}" => '1.94591014905531',
                                  'ur' => '6.33327962813969',
                                  'bp' => '3.63758615972639',
                                  "m\x{17e}" => '5.31320597904179',
                                  "\x{165}t" => '3.58351893845611',
                                  'dt' => '6.11146733950268',
                                  "a\x{10d}" => '6.16541785423142',
                                  'tw' => '4.04305126783455',
                                  "\x{161}f" => '2.07944154167984',
                                  "r\x{161}" => '4.36944785246702',
                                  'ce' => '7.68202151082687',
                                  "\x{10f}n" => '3.04452243772342',
                                  "j\x{10d}" => '3.93182563272433',
                                  "j\x{159}" => '2.56494935746154',
                                  'ev' => '7.49052940206071',
                                  'at' => '8.27026911143662',
                                  "c\x{17e}" => '2.484906649788',
                                  'pi' => '6.12468339089421',
                                  'tg' => '6.44094654063292',
                                  "\x{148}z" => '2.07944154167984',
                                  'ou' => '8.22469956196723',
                                  "\x{17e}l" => '4.14313472639153',
                                  "\x{17e}p" => '5.08759633523238',
                                  "\x{148}p" => '2.83321334405622',
                                  'te' => '8.51057131510735',
                                  'ig' => '5.5683445037611',
                                  'ns' => '7.13568734702814',
                                  "\x{17e}c" => '4.55387689160054',
                                  "\x{159}b" => '3.78418963391826',
                                  'jf' => '2.484906649788',
                                  'hf' => '3.76120011569356',
                                  "\x{17e}\x{10f}" => '1.79175946922805',
                                  "\x{10d}\x{159}" => '0',
                                  'fg' => '1.09861228866811',
                                  "\x{165}z" => '1.38629436111989'
                                },
                    'log_n' => {
                                 "\x{159}" => '8.52931937121408',
                                 'a' => '10.627454875436',
                                 "\x{161}" => '8.40782465436087',
                                 'd' => '9.92642252381862',
                                 'j' => '9.34775172779914',
                                 'y' => '9.33414965770247',
                                 'u' => '9.7225050987434',
                                 'k' => '9.75469747895097',
                                 'g' => '8.23668532271246',
                                 "\x{13e}" => '0',
                                 't' => '10.4374631362008',
                                 "\x{16f}" => '7.42117752859539',
                                 'e' => '10.8271708916298',
                                 "\x{11d}" => '0.693147180559945',
                                 "\x{109}" => '0.693147180559945',
                                 'v' => '9.80477157959697',
                                 's' => '10.1661210115368',
                                 'c' => '9.5502353158749',
                                 'b' => '9.19461741151095',
                                 'q' => '5.62401750618734',
                                 'z' => '9.07966204833407',
                                 'w' => '7.58375630070711',
                                 "\x{135}" => '0',
                                 'r' => '9.99360244197839',
                                 'x' => '5.47646355193151',
                                 "\x{10d}" => '8.22309055116153',
                                 'h' => '9.67765288341043',
                                 "\x{11b}" => '8.92877290052426',
                                 'f' => '8.20330402679528',
                                 'i' => '10.2585361747303',
                                 "\x{10f}" => '6.05443934626937',
                                 "\x{16d}" => '4.24849524204936',
                                 'n' => '10.4061701113597',
                                 'm' => '9.79378428744416',
                                 'l' => '10.3164908436826',
                                 'p' => '9.69301340432258',
                                 "\x{17e}" => '8.59452453435256',
                                 "\x{148}" => '5.62762111369064',
                                 "\x{165}" => '6.06378520868761',
                                 'o' => '10.7018277347242'
                               },
                    'log_sigma_n' => '13.1748438667969'
                  }
        };
 }

1;

__END__

=head1 NAME
 
MultiLM - A toy multi-language model

This documentation covers both the module which implements the model, and the compiler which
generates a trained module.

=head1 USAGE

Using the module
 
    use MultiLM;

    my $lm = MultiLM->new;

    my $h  = $lm->prob_language($txt);
    my ($best) = sort { $h->{$b} <=> $h->{$a} } keys %$h;
    
    printf "Text is probably %s (%d%%)\n", $best, 100.0 * $h->{$best};

=cut

=pod

=head1 MODEL DESCRIPTION

The model is a simple letter-pair frequency model, though the API
below should hide this detail.

=head1 PUBLIC METHODS

=over

=item new()

The constructor. No arguments!

=item languages

Return the list of languages the model knows about.

=item logprob_string($text)

Return a hash from language to log prob(text|language).

=item prob_language($text)

Return a has from language to prob(language|text). Note, this assumes
that a priori all languages are equiprobable.

=item init_learning

Put the module into learning mode: after this the model will discard
any data stored in the .pm file.

=item learn_string($lang, $text)

Add C<text> to the model, assuming that it's written in language C<lang>.

=item model

Return the model as a Perl data structure.

=item as_text

Return a brief textual summary of the model.

=item save_as_perl($file)

Write the entire model to C<file> (which defaults to MultiLM.pm).

=back

=head1 BUGS AND LIMITATIONS

It's a quick hack, so the model's just a toy, and probably a buggy toy at that.

Please report problems to the author.

Patches are welcome.
 
=head1 AUTHOR

Martin Oldfield, <m@mjo.tc>
 
=head1 LICENCE AND COPYRIGHT
 
Copyright (c) 2010, Martin Oldfield. All rights reserved.
 
This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=cut

